<?php
/**
 * Dynamic CSS for the frontend.
 *
 * @package Capture
 */

defined( 'WPINC' ) || exit;

/**
 * Helper function.
 * Merge and combine the CSS elements.
 *
 * @param  string|array $elements An array of our elements.
 *                                If we use a string then it is directly returned.
 * @return string
 */
function capture_implode( $elements = [] ) {

	if ( ! is_array( $elements ) ) {
		return $elements;
	}

	// Make sure our values are unique.
	$elements = array_unique( $elements );

	// Sort elements alphabetically.
	// This way all duplicate items will be merged in the final CSS array.
	sort( $elements );

	// Implode items and return the value.
	return implode( ',', $elements );

}

/**
 * Maps elements from dynamic css to the selector.
 *
 * @param  array  $elements The elements.
 * @param  string $selector The selector.
 * @return array
 */
function capture_map_selector( $elements, $selector ) {
	$array = [];

	foreach ( $elements as $element ) {
		$array[] = $element . $selector;
	}

	return $array;
}

/**
 * Map CSS selectors from values.
 *
 * @param array $css    Array of dynamic CSS.
 * @param array $values Array of values.
 */
function capture_map_css_selectors( &$css, $values ) {
	if ( isset( $values['css-selectors'] ) ) {
		$elements = $values['css-selectors'];
		unset( $values['css-selectors'] );

		$css[ $elements ] = $values;
	}
}

/**
 * Merge CSS values.
 *
 * @param array $css    Array of dynamic CSS.
 * @param array $values Array of values.
 */
function capture_merge_value( &$css, $values ) {
	foreach ( $values as $id => $val ) {
		$css[ $id ] = $val;
	}
}

/**
 * Format of the $css array:
 * $css['media-query']['element']['property'] = value
 *
 * If no media query is required then set it to 'global'
 *
 * If we want to add multiple values for the same property then we have to make it an array like this:
 * $css[media-query][element]['property'][] = value1
 * $css[media-query][element]['property'][] = value2
 *
 * Multiple values defined as an array above will be parsed separately.
 */
function capture_dynamic_css_array() {

	global $wp_version;

	$css       = [];
	$c_page_id = capture()->get_page_id();

	// Site Background.
	$css['global']['html body'] = Capture_Sanitize::background( capture_get_settings( 'theme_background' ) );

	// Header Background.
	$css['global']['#site-header'] = Capture_Sanitize::background( capture_get_settings( 'header_background' ) );

	// Logo Font.
	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'capture_logo' ) ) );
	// Footer Logo Font.
	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'capture_footer_logo' ) ) );
	// Primary Navigation font.
	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'primary_navigation_font' ) ) );
	// Content Font.
	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'content_font' ) ) );
	// Pagination.
	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'pagination_font' ) ) );
	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'loadmore_font' ) ) );
	// Single post title font.
	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'single_title_font' ) ) );
	// Single post author info font.
	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'single_author_meta_info_font' ) ) );
	// Single Page titles font.
	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'single_page_titles_font' ) ) );
	// Single subscribe box.
	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'single_subscribe_title_font' ) ) );
	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'single_subscribe_text_font' ) ) );
	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'single_subscribe_input_font' ) ) );
	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'single_subscribe_submit_font' ) ) );
	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'single_subscribe_small_text_font' ) ) );
	// Author Box.
	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'authorbox_title_font' ) ) );
	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'authorbox_author_name_font' ) ) );
	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'authorbox_text_font' ) ) );
	// Footer Nav.
	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'footer_nav_font' ) ) );
	// Sidebar widget title font.
	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'sidebar_title_font' ) ) );
	// Sidebar widget font.
	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'sidebar_font' ) ) );
	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'sidebar_links_widgets' ) ) );
	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'sidebar_post_title' ) ) );
	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'sidebar_large_post_title' ) ) );
	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'sidebar_postinfo_font' ) ) );
	// Footer widget title font.
	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'top_footer_title_font' ) ) );
	// Footer widget font.
	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'top_footer_font' ) ) );
	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'footer_links_widgets' ) ) );
	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'top_footer_post_title' ) ) );
	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'footer_large_post_title' ) ) );
	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'top_footer_meta_font' ) ) );
	// Copyrights section font.
	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'copyrights_font' ) ) );
	// Fields font.
	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'fields_font' ) ) );
	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'buttons_font' ) ) );
	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'blockquote_font' ) ) );
	// H1 title in the content.
	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'h1_headline' ) ) );
	// H2 title in the content.
	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'h2_headline' ) ) );
	// H3 title in the content.
	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'h3_headline' ) ) );
	// H4 title in the content.
	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'h4_headline' ) ) );
	// H5 title in the content.
	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'h5_headline' ) ) );
	// H6 title in the content.
	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'h6_headline' ) ) );

	// Footer background.
	$css['global']['#site-footer'] = Capture_Sanitize::background( capture_get_settings( 'mts_footer_background' ) );
	// Copyrights background.
	$css['global']['.copyrights'] = Capture_Sanitize::background( capture_get_settings( 'mts_copyrights_background' ) );
	// Sidebar Subscribe Widget.
	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'subscribe_widget_title_font' ) ) );
	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'sidebar_fields_font' ) ) );
	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'subscribe_widget_text_font' ) ) );
	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'subscribe_widget_submit_font' ) ) );
	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'subscribe_widget_small_text_font' ) ) );
	// Footer Subscribe Widget.
	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'footer_subscribe_widget_title_font' ) ) );
	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'footer_fields_font' ) ) );
	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'footer_subscribe_widget_text_font' ) ) );
	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'footer_subscribe_widget_submit_font' ) ) );
	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'footer_subscribe_widget_small_text_font' ) ) );

	capture_dynamic_css_skin( $css );
	capture_sidebar_position( $css );
	capture_header( $css );
	capture_sidebar_styling( $css );
	capture_page_titles( $css );
	capture_post_layouts( $css );
	capture_post_pagination( $css );
	capture_footer( $css );
	capture_social_nav_footer( $css );
	capture_copyrights( $css );
	capture_single( $css );
	capture_single_photos_cpt( $css );
	capture_single_social_buttons( $css );
	capture_archive_post( $css );
	capture_misc_css( $css );
	capture_custom_posts( $css );

	return apply_filters( 'capture_dynamic_css_array', $css );
}

/**
 * Skin CSS
 *
 * @param array $css Array of dynamic CSS.
 */
function capture_dynamic_css_skin( &$css ) {

	// Colors.
	$primary_color_scheme   = Capture_Sanitize::color( capture_get_settings( 'primary_color_scheme' ) );
	$secondary_color_scheme = Capture_Sanitize::color( capture_get_settings( 'secondary_color_scheme' ) );

	// Text Color.
	$elements = [
		'a',
		'body a:hover',
		'.woocommerce ul.products li.product .price',
		'.product_list_widget .amount',
		'.woocommerce div.product p.price, .woocommerce div.product span.price',
		'.textwidget a',
		'#wp-calendar td#today',
		'.pnavigation2 a',
		'#tabber .inside li a:hover',
		'.fn a',
		'.related-posts .title a:hover',
		'blockquote:after',
		'article ul li::before',
		'.single .pagination a .current:hover',
		'blockquote::before',
		'.postauthor h5 a:hover',
		'.widget .sbutton:hover',
		'.shareit-circular.standard .share-text',
		'.breadcrumb a',
		'.rank-math-breadcrumb a',
		'.layout-default .readMore a:hover',
		'.instagram-button a',
		'.reply a:hover',
		'.featured-section .title span',
		'.aboutme-widget .aboutme-social a:hover',
		'.toggle-menu .toggle-caret .fa',
		'.widget.social-profile-icons a:hover',
		'.single_post .post-info a:hover',
		'#commentform p .fa',
		'.layout-default .latestPost .post-info a:hover',
		'.single-full-header .prev-next a:hover',
		'.single-photos .single_post .post-info a:hover',
		'.single-full-header .post-info a:hover',
		'.widget li a:hover',
		'.f-widget .widget li a:hover',
	];

	$css['global'][ capture_implode( $elements ) ]['color'] = $primary_color_scheme;
	// social svg hover color.
	$css['global']['.shareit-circular.standard svg:hover']['fill'] = $secondary_color_scheme;

	// Background Color.
	$elements = [
		'.pace .pace-progress',
		'#mobile-menu-wrapper ul li a:hover',
		'.pagination a:hover',
		'.single .pagination a:hover .current',
		'.navigation #wpmm-megamenu .wpmm-pagination a',
		'.wpmm-megamenu-showing.wpmm-light-scheme',
		'#move-to-top:hover',
		'#tabber ul.tabs li a.selected',
		'.navigation ul .sfHover a',
		'.widget-slider .slide-caption',
		'#wpmm-megamenu .review-total-only',
		'#searchsubmit',
		'.woocommerce .widget_price_filter .ui-slider .ui-slider-handle',
		'.woocommerce .widget_price_filter .ui-slider .ui-slider-range',
		'.woocommerce span.onsale',
		'.woocommerce .bypostauthor:after',
		'.woocommerce-account .woocommerce-MyAccount-navigation li.is-active',
		'.widget .widget_wp_review_tab .review-total-only.large-thumb',
		'.pagination .nav-previous a:hover',
		'.pagination .nav-next a:hover',
		'.woocommerce a.button:hover', // WooCommerce.
		'.woocommerce-page a.button:hover',
		'.woocommerce button.button:hover',
		'.woocommerce-page button.button:hover',
		'.woocommerce input.button:hover',
		'.woocommerce-page input.button:hover',
		'.woocommerce #respond input#submit:hover',
		'.woocommerce-page #respond input#submit:hover',
		'.woocommerce #content input.button:hover',
		'.woocommerce-page #content input.button:hover',
		'#add_payment_method .wc-proceed-to-checkout a.checkout-button:hover',
		'.woocommerce-cart .wc-proceed-to-checkout a.checkout-button:hover',
		'.woocommerce-checkout .wc-proceed-to-checkout a.checkout-button:hover',
		'.woocommerce a.button.alt:hover',
		'.woocommerce button.button.alt:hover',
		'.woocommerce input.button.alt:hover',
		'.woocommerce .woocommerce-widget-layered-nav-dropdown__submit:hover',
		'.woocommerce div.product form.cart .button:hover',
		'.owl-prev',
		'.owl-next',
		'.single-subscribe .widget #wp-subscribe input.submit',
		'.button:hover',
		'#commentform input#submit',
		'#mtscontact_submit',
		'.woocommerce .widget.widget_product_search button[type="submit"]',
		'.woocommerce-page .widget.widget_product_search button[type="submit"]',
		'.widget .wp_review_tab_widget_content ul.wp-review-tabs li.selected a::before',
		'.widget .wpt_widget_content ul.wpt-tabs li.selected a::before',
		'.woocommerce #respond input#submit.disabled',
		'.woocommerce #respond input#submit:disabled',
		'.woocommerce #respond input#submit:disabled[disabled]',
		'.woocommerce a.button.disabled',
		'.woocommerce a.button:disabled',
		'.woocommerce a.button:disabled[disabled]',
		'.woocommerce button.button.disabled',
		'.woocommerce button.button:disabled',
		'.woocommerce button.button:disabled[disabled]',
		'.woocommerce input.button.disabled',
		'.woocommerce input.button:disabled',
		'.woocommerce input.button:disabled[disabled]',
		'.woocommerce nav.woocommerce-pagination ul li span.current',
		'.woocommerce nav.woocommerce-pagination ul li a:hover',
		'.woocommerce nav.woocommerce-pagination ul li a:focus',
		'.woocommerce-page nav.woocommerce-pagination ul li span.current',
		'.woocommerce-page nav.woocommerce-pagination ul li a:hover',
		'.woocommerce-page nav.woocommerce-pagination ul li a:focus',
	];

	$css['global'][ capture_implode( $elements ) ]['background-color'] = $primary_color_scheme;

	$css['@media screen and (max-width: 865px)']['.navigation.mobile-menu-wrapper']['background-color'] = Capture_Sanitize::color( capture_get_settings( 'nav_background' ) );

	$css['global']['.single-full-header .prev-next a:hover path']['stroke'] = $primary_color_scheme;

	// Secondary Color.
	$elements = [
		'.owl-prev:hover',
		'.owl-next:hover',
		'.single-subscribe .widget #wp-subscribe input.submit:hover',
		'#commentform input#submit:hover',
		'#mtscontact_submit:hover',
		'.woocommerce .widget.widget_product_search button[type="submit"]:hover',
		'.woocommerce-page .widget.widget_product_search button[type="submit"]:hover',
	];

	$css['global'][ capture_implode( $elements ) ]['background'] = $secondary_color_scheme;

	$css['global']['.shareit-circular.circular-standard .social-icon:hover']['background'] = $secondary_color_scheme . '!important';

	// Secondary Color.
	$elements = [
		'.latestPost .title a:hover',
		'.related-posts .latestPost .title a:hover',
		'.layout-default .latestPost .title a:hover',
		'.layout-1 .latestPost .title a:hover',
		'.layout-2 .latestPost .title a:hover',
		'.sidebar .post-title a:hover',
		'.sidebar .entry-title a:hover',
		'.sidebar .wpt_comment_meta a:hover',
		'.widget .product_list_widget .product-title:hover',
		'.widget .cart_list a:hover',
		'.shareit-circular.standard .fa:hover',
		'.single_post .post-info a:hover',
		'.single-full-header.single-cpt-photo .post-info a:hover',
		'.tags a:hover',
		'.aboutme-widget .aboutme-social a:hover',
		'.single_post a:hover',
		'.single_page a:hover',
	];

	$css['global'][ capture_implode( $elements ) ]['color'] = $secondary_color_scheme;

	// Links Widgets Hover Color.
	$elements = [
		'.widget.widget_archive a:hover',
		'.widget.widget_categories a:hover',
		'.widget.widget_pages a:hover',
		'.widget.widget_meta a:hover',
		'.widget.widget_nav_menu a:hover',
		'.tagcloud a:hover',
		'.widget .wpt_widget_content #tags-tab-content ul li a:hover',
		'.widget .post-title a:hover',
		'.widget .entry-title a:hover',
		'.widget .wpt_comment_meta a:hover',
		'.widget .wpt_thumb_large + .entry-title a:hover',
		'.widget .review_thumb_large .entry-title a:hover',
		'.widget .wpt_thumb_large + .wpt_comment_meta a:hover',
	];

	$css['global'][ capture_implode( $elements ) ]['color'] = $secondary_color_scheme . ' ! important';

	// Border Color.
	$elements = [
		'.page-numbers.current',
		'.pagination a:hover',
		'input#author',
		'.contact-form input[type="text"]',
		'input#email',
		'input#url',
		'#commentform textarea',
		'.contact-form textarea',
		'.woocommerce #respond input#submit:hover',
		'.woocommerce a.button:hover',
		'.woocommerce button.button:hover',
		'.woocommerce input.button:hover',
		'.woocommerce div.product form.cart .button:hover',
		'.woocommerce .woocommerce-widget-layered-nav-dropdown__submit:hover',
		'.woocommerce nav.woocommerce-pagination ul li span.current',
		'.woocommerce nav.woocommerce-pagination ul li a:hover',
		'.woocommerce nav.woocommerce-pagination ul li a:focus',
		'.woocommerce-page nav.woocommerce-pagination ul li span.current',
		'.woocommerce-page nav.woocommerce-pagination ul li a:hover',
		'.woocommerce-page nav.woocommerce-pagination ul li a:focus',
	];

	$css['global'][ capture_implode( $elements ) ]['border-color'] = $primary_color_scheme;

}

/**
 * Sidebar Position
 *
 * @param array $css Array of dynamic CSS.
 */
function capture_sidebar_position( &$css ) {

	// Sidebar position.
	$sidebar_position = capture_get_settings( 'theme_layout' );

	$sidebar_metabox_location = '';
	if ( is_page() || is_single() ) {
		$sidebar_metabox_location = get_post_meta( get_the_ID(), '_mts_sidebar_location', true );
	}

	if ( 'right' !== $sidebar_metabox_location && ( 'sclayout' === $sidebar_position || 'left' === $sidebar_metabox_location ) ) {
		$css['global']['.article']['float']                = 'right';
		$css['global']['.sidebar.c-4-12']['float']         = 'left';
		$css['global']['.sidebar.c-4-12']['padding-right'] = 0;

		if ( null !== capture_get_settings( 'mts_social_button_position' ) && 'floating' === capture_get_settings( 'mts_social_button_position' ) ) {

			$shareit_class = [
				'.sclayout .shareit.shareit-default.floating',
				'.sclayout .shareit.standard.floating',
				'.sclayout .shareit.shareit-circular.floating',
			];

			$css['global'][ capture_implode( $shareit_class ) ]['left']  = 'auto';
			$css['global'][ capture_implode( $shareit_class ) ]['right'] = '0px';

			$css['global'][ capture_implode( $shareit_class ) ]['margin-left']  = '0px';
			$css['global'][ capture_implode( $shareit_class ) ]['margin-right'] = capture_px2rem( '100px' );
		}
	}
	$sidebar_meta_info_class = '.sidebar .post-info > span:after';
	$sidebar_meta_info_font  = capture_get_settings( 'sidebar_postinfo_font' );
	// Sidebar Meta divider.
	$css['global'][ $sidebar_meta_info_class ]['background-color'] = Capture_Sanitize::color( $sidebar_meta_info_font['color'] );
	// bullet styling.
	$sidebar_bullet = [
		'.sidebar .widget.widget_categories li:after',
		'.sidebar .widget.widget_archive li:after',
		'.sidebar .widget.widget_pages li:after',
		'.sidebar .widget.widget_meta li:after',
		'.sidebar .widget.widget_recent_comments li:after',
		'.sidebar .widget.widget_recent_entries li:after',
		'.sidebar .widget.widget_rss li:after',
		'.sidebar .widget.widget_nav_menu li:after',
		'.widget .product-categories li:after',
		'.widget .woocommerce-widget-layered-nav-list .woocommerce-widget-layered-nav-list__item:after',
	];
	$sidebar_links_widgets = capture_get_settings( 'sidebar_links_widgets' );
	$css['global'][ capture_implode( $sidebar_bullet ) ]['background-color'] = Capture_Sanitize::color( $sidebar_links_widgets['color'] );
}

/**
 * Header
 *
 * @param array $css Array of dynamic CSS.
 */
function capture_header( &$css ) {
	$header_class = '#header';
	// background.
	$css['global'][ $header_class ] = Capture_Sanitize::background( capture_get_settings( 'header_background' ) );
	capture_merge_value( $css['global'][ $header_class ], Capture_Sanitize::margin( capture_get_settings( 'header_margin' ) ) );
	capture_merge_value( $css['global'][ $header_class ], Capture_Sanitize::padding( capture_get_settings( 'header_padding' ) ) );

	// Header Border.
	$header_border = Capture_Sanitize::border( capture_get_settings( 'header_border' ) );
	$css['global'][ $header_class . ':after' ][ $header_border['direction'] ] = $header_border ['value'];

	$css['global']['#primary-navigation .navigation ul ul a']['color']            = Capture_Sanitize::color( capture_get_settings( 'main_navigation_dropdown_color' ) );
	$css['global']['#primary-navigation .navigation ul ul']['background']         = Capture_Sanitize::color( capture_get_settings( 'main_navigation_dropdown_background' ) );
	$css['global']['#primary-navigation .navigation ul ul']['border-radius']      = Capture_Sanitize::size( capture_get_settings( 'main_navigation_dropdown_border_radius' ) . 'px' );
	$css['global']['#primary-navigation .navigation ul li:hover > a']['color']    = Capture_Sanitize::color( capture_get_settings( 'main_navigation_hover_color' ) );
	$css['global']['#primary-navigation .navigation ul ul li:hover > a']['color'] = Capture_Sanitize::color( capture_get_settings( 'main_navigation_dropdown_hover_color' ) );
	// Nav Padding.
	capture_merge_value( $css['global']['#primary-navigation'], Capture_Sanitize::padding( capture_get_settings( 'header_nav_padding' ) ) );
	// Social icons.
	$header_icons = capture_get_settings( 'header_social_icons' );
	if ( ! empty( $header_icons ) && is_array( $header_icons ) ) :
		foreach ( $header_icons as $header_icon ) :
			$css['global'][ '.header-social-icons a.header-' . $header_icon['header_icon'] ]['background-color']            = Capture_Sanitize::color( $header_icon['header_icon_bgcolor'] );
			$css['global'][ '.header-social-icons a.header-' . $header_icon['header_icon'] . ':hover' ]['background-color'] = Capture_Sanitize::color( $header_icon['header_icon_hover_bgcolor'] );
			$css['global'][ '.header-social-icons a.header-' . $header_icon['header_icon'] ]['color']                       = Capture_Sanitize::color( $header_icon['header_icon_color'] );
			$css['global'][ '.header-social-icons a.header-' . $header_icon['header_icon'] . ':hover' ]['color']            = Capture_Sanitize::color( $header_icon['header_icon_hover_color'] );
			capture_merge_value( $css['global'][ '.header-social-icons a.header-' . $header_icon['header_icon'] ], Capture_Sanitize::margin( $header_icon['header_icon_margin'] ) );
			capture_merge_value( $css['global'][ '.header-social-icons a.header-' . $header_icon['header_icon'] ], Capture_Sanitize::padding( $header_icon['header_icon_padding'] ) );
			$css['global'][ '.header-social-icons a.header-' . $header_icon['header_icon'] ]['border-radius'] = Capture_Sanitize::size( $header_icon['header_icon_border_radius'] . 'px' );
		endforeach;
	endif;

	// Header Ad.
	capture_merge_value( $css['global']['.widget-header, .small-header .widget-header'], Capture_Sanitize::margin( capture_get_settings( 'mts_header_adcode_margin' ) ) );

	// Ad-Blocker.
	$css['global']['.navigation-banner']['background'] = Capture_Sanitize::color( capture_get_settings( 'navigation_ad_background' ) );

	// Floating Navigation Responsive.
	if ( ! capture_get_settings( 'sticky_responsive_nav' ) ) :
		$css['@media screen and (max-width: 865px)']['#catcher']['height'] = '0px!important';
		// position relative!important.
		$css['@media screen and (max-width: 865px)']['.sticky-navigation-active, .admin-bar .sticky-navigation-active']['top']  = '0px!important';
		$css['@media screen and (max-width: 865px)']['.sticky-navigation-active, #header.sticky-navigation-active']['position'] = 'relative!important';
	endif;

	if ( ! capture_get_settings( 'header_search_box' ) ) :
		$header_search_box = [
			'#site-header .header-search + #primary-navigation',
			'#site-header .header-search + .header-social-icons',
		];
		$css['global'][ capture_implode( $header_search_box ) ]['margin-right'] = '0px!important';
	endif;
}

/**
 * Social Share Styling
 *
 * @param array $css Array of dynamic CSS.
 */
function capture_single_social_buttons( &$css ) {

	// Social share.
	$css['global']['.shareit.floating'] = Capture_Sanitize::background( capture_get_settings( 'social_styling_background' ) );
	capture_merge_value( $css['global']['.shareit.floating'], Capture_Sanitize::margin( capture_get_settings( 'social_styling_margin' ) ) );

	// Social share border.
	$social_border = Capture_Sanitize::border( capture_get_settings( 'social_styling_border' ) );
	$css['global']['.shareit.floating'][ $social_border ['direction'] ] = $social_border ['value'];

	$social_button_layout   = capture_get_settings( 'social_button_layout' );
	$social_button_position = capture_get_settings( 'social_floating_button_position' );
	if ( 'default' === $social_button_layout ) {
		$share_class = '.shareit.shareit-' . $social_button_layout . '.floating';
	} else {
		$share_class = '.shareit.' . $social_button_layout . '.floating';
	}
	if ( ! empty( $social_button_position ) && is_array( $social_button_position ) ) {
		foreach ( $social_button_position as $key => $position ) {
			$css['global'][ $share_class ][ $key ] = $position;
		}
	}
	// Tags & Social.
	$position = capture_get_settings( 'mts_social_button_position' );
	if ( 'floating' === $position ) :
		$css['global']['.social-tags:before']['display'] = 'none';
		// Responsive screen.
		$css['@media screen and (max-width: 1260px)']['.social-tags:before']['display'] = 'block';
	endif;
}

/**
 * Sidebar styling
 *
 * @param array $css Array of dynamic CSS.
 */
function capture_sidebar_styling( &$css ) {

	// Sidebar.
	capture_merge_value( $css['global']['.widget, .f-widget .widget'], Capture_Sanitize::background( capture_get_settings( 'sidebar_styling_background' ) ) );
	capture_merge_value( $css['global']['.widget, .f-widget .widget'], Capture_Sanitize::margin( capture_get_settings( 'sidebar_styling_margin' ) ) );
	capture_merge_value( $css['global']['.widget, .f-widget .widget'], Capture_Sanitize::padding( capture_get_settings( 'sidebar_styling_padding' ) ) );

	// Sidebar border.
	$sidebar_border = Capture_Sanitize::border( capture_get_settings( 'sidebar_styling_border' ) );
	$css['global']['.widget, .f-widget .widget'][ $sidebar_border['direction'] ] = $sidebar_border['value'];

	// Sidebar title.
	$sidebar_title                   = '#sidebar .widget h3';
	$css['global'][ $sidebar_title ] = Capture_Sanitize::background( capture_get_settings( 'sidebar_title_styling_background' ) );
	capture_merge_value( $css['global'][ $sidebar_title ], Capture_Sanitize::padding( capture_get_settings( 'sidebar_title_styling_padding' ) ) );
	capture_merge_value( $css['global'][ $sidebar_title ], Capture_Sanitize::margin( capture_get_settings( 'sidebar_title_styling_margin' ) ) );

	// Sidebar Title border.
	$sidebar_title_border = Capture_Sanitize::border( capture_get_settings( 'widget_title_border' ) );
	$css['global'][ $sidebar_title ][ $sidebar_title_border['direction'] ] = $sidebar_title_border['value'];
	// Subscribe Box.
	$css['global']['.widget.wp_subscribe'] = Capture_Sanitize::background( capture_get_settings( 'subscribe_widget_background' ) );
	capture_merge_value( $css['global']['.widget.wp_subscribe'], Capture_Sanitize::padding( capture_get_settings( 'subscribe_widget_padding' ) ) );
	$subscribe_border = Capture_Sanitize::border( capture_get_settings( 'subscribe_widget_border' ) );
	$css['global']['.widget.wp_subscribe'][ $subscribe_border ['direction'] ] = $subscribe_border ['value'];
	// Subscribe Box Submit button.
	$css['global']['.widget #wp-subscribe input.submit']['background'] = Capture_Sanitize::color( capture_get_settings( 'subscribe_widget_submit_backgroud' ) );

}

/**
 * Pages Title and Breadcrumb
 *
 * @param array $css Array of dynamic CSS.
 */
function capture_page_titles( &$css ) {
	// Typography.
	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'pages_title_font' ) ) );
	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'pages_subtitle_font' ) ) );
	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'breadcrumb_font' ) ) );

	// Margin and Padding.
	capture_merge_value( $css['global']['.pages-title-section'], Capture_Sanitize::background( capture_get_settings( 'pages_title_background' ) ) );
	capture_merge_value( $css['global']['.pages-title-section'], Capture_Sanitize::margin( capture_get_settings( 'pages_title_margin' ) ) );
	capture_merge_value( $css['global']['.pages-title-section'], Capture_Sanitize::padding( capture_get_settings( 'pages_title_padding' ) ) );

}

/**
 * Layout CSS
 *
 * @param array $css Array of dynamic CSS.
 */
function capture_post_layouts( &$css ) {

	// Post Layouts.
	$features = capture_get_settings( 'featured_categories' );
	foreach ( $features as $feature ) :

		if ( ! isset( $feature['unique_id'] ) ) {
			continue;
		}

		$category     = $feature['mts_featured_category'];
		$posts_layout = isset( $feature['blog_layout'] ) ? $feature['blog_layout'] : 'layout-default';
		$unique_id    = $feature['unique_id'];

		if ( 'layout-default' === $posts_layout ) :
			$posts_layout = 'default';
		endif;

		// Section title align.
		$post_title_align = capture_get_settings( 'post_title_alignment_' . $unique_id );

		// Post area.
		$cat_class = 'cat-latest';
		if ( 'latest' !== $category ) {
			$category  = get_term_by( 'slug', $category, 'category' );
			$cat_class = sanitize_key( $category->name );
		}

		$title_class = '.title-container.title-id-' . $unique_id . ' h3';

		$css['global'][ $title_class ] = Capture_Sanitize::background( capture_get_settings( 'featured_category_title_background_' . $unique_id ) );
		capture_merge_value( $css['global'][ $title_class ], Capture_Sanitize::margin( capture_get_settings( 'featured_category_title_margin_' . $unique_id ) ) );
		capture_merge_value( $css['global'][ $title_class ], Capture_Sanitize::padding( capture_get_settings( 'featured_category_title_padding_' . $unique_id ) ) );
		// Section title border.
		$post_title_border = Capture_Sanitize::border( capture_get_settings( 'post_title_border_' . $unique_id ) );
		$css['global'][ $title_class ][ $post_title_border['direction'] ] = $post_title_border['value'];

		// Title alignment.
		$align_class = '.title-container.title-id-' . $unique_id;
		if ( 'center' === $post_title_align ) :
			$css['global'][ $align_class ]['text-align'] = 'center';
		elseif ( 'right' === $post_title_align ) :
			$css['global'][ $align_class ]['text-align'] = 'right';
		endif;

		capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'featured_category_title_font_' . $unique_id ) ) );

		if ( 'layout-default' === $posts_layout ) {
			$post_class = '.layout-' . $unique_id . '.default-container';
		} else {
			$post_class = '.layout-' . $unique_id;
		}

		// Post border.
		$post_border = Capture_Sanitize::border( capture_get_settings( 'post_border_' . $unique_id ) );
		$css['global'][ $post_class ][ $post_border['direction'] ] = $post_border['value'];

		/**
		 * Meta info
		 */
		capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'meta_info_font_' . $unique_id ) ) );
		capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'readmore_font_' . $unique_id ) ) );

		capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'post_title_font_' . $unique_id ) ) );
		capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'post_excerpt_font_' . $unique_id ) ) );

		// All Posts Margin and Padding.
		capture_merge_value( $css['global'][ $post_class ], Capture_Sanitize::margin( capture_get_settings( 'post_margin_' . $unique_id ) ) );
		capture_merge_value( $css['global'][ $post_class ], Capture_Sanitize::padding( capture_get_settings( 'post_padding_' . $unique_id ) ) );

		$readmore_border = Capture_Sanitize::border( capture_get_settings( 'readmore_border_' . $unique_id ) );
		$css['global'][ $post_class . ' .readMore a' ][ $readmore_border ['direction'] ] = $readmore_border['value'];
		// Color Options.
		$css['global'][ $post_class . ' .readMore a' ]['background']         = Capture_Sanitize::color( capture_get_settings( 'readmore_bg_color_' . $unique_id ) );
		$css['global'][ $post_class . ' .readMore a:hover' ]['background']   = Capture_Sanitize::color( capture_get_settings( 'readmore_bg_hover_color_' . $unique_id ) );
		$css['global'][ $post_class . ' .readMore a:hover' ]['color']        = Capture_Sanitize::color( capture_get_settings( 'readmore_hover_color_' . $unique_id ) );
		$css['global'][ $post_class . ' .readMore a:hover' ]['border-color'] = Capture_Sanitize::color( capture_get_settings( 'readmore_border_hover_color_' . $unique_id ) );
		capture_merge_value( $css['global'][ $post_class . ' .readMore a' ], Capture_Sanitize::padding( capture_get_settings( 'readmore_btn_padding_' . $unique_id ) ) );

		// Post Alignment.
		$post_alignment       = capture_get_settings( 'post_alignment_' . $unique_id );
		$post_alignment_class = [
			'.layout-' . $unique_id . ' .latestPost',
		];
		if ( 'center' === $post_alignment ) :
			$css['global'][ capture_implode( $post_alignment_class ) ]['text-align'] = 'center';
		endif;
		if ( 'right' === $post_alignment ) :
			$css['global'][ capture_implode( $post_alignment_class ) ]['text-align'] = 'right';
		endif;

		// Post Meta Info Divider.
		$post_meta_info_class = [
			'.layout-' . $unique_id . ' .latestPost .post-info > span:after',
		];
		$post_meta_info_font  = capture_get_settings( 'meta_info_font_' . $unique_id );
		$css['global'][ capture_implode( $post_meta_info_class ) ]['background-color'] = Capture_Sanitize::color( $post_meta_info_font['color'] );
	endforeach;
}

/**
 * Pagination
 *
 * @param array $css Array of dynamic CSS.
 */
function capture_post_pagination( &$css ) {

	// Pagination Active class.
	$pagination_class_active = [
		'.pace .pace-progress',
		'.page-numbers.current',
		'.pagination a:hover',
		'.single .pagination > .current .currenttext',
		'#mobile-menu-wrapper ul li a:hover',
		'#load-posts a:hover',
	];
	$pagination_class        = [
		'.pagination a',
		'#load-posts a',
		'.pagination .page-numbers.dots',
		'.page-numbers.current',
	];
	if ( '2' !== capture_get_settings( 'mts_pagenavigation_type' ) ) {
		$css['global'][ capture_implode( $pagination_class ) ]['background-color']        = Capture_Sanitize::color( capture_get_settings( 'mts_pagenavigation_bgcolor' ) );
		$css['global'][ capture_implode( $pagination_class_active ) ]['background-color'] = Capture_Sanitize::color( capture_get_settings( 'mts_pagenavigation_hover_bgcolor' ) );
		$css['global'][ capture_implode( $pagination_class ) ]['color']                   = Capture_Sanitize::color( capture_get_settings( 'mts_pagenavigation_color' ) );
		$css['global'][ capture_implode( $pagination_class_active ) ]['color']            = Capture_Sanitize::color( capture_get_settings( 'mts_pagenavigation_hover_color' ) );
		$css['global'][ capture_implode( $pagination_class_active ) ]['border-color']     = Capture_Sanitize::color( capture_get_settings( 'mts_pagenavigation_hover_bgcolor' ) );
		capture_merge_value( $css['global'][ capture_implode( array_merge( $pagination_class_active, $pagination_class ) ) ], Capture_Sanitize::margin( capture_get_settings( 'mts_pagenavigation_margin' ) ) );
		capture_merge_value( $css['global'][ capture_implode( array_merge( $pagination_class_active, $pagination_class ) ) ], Capture_Sanitize::padding( capture_get_settings( 'mts_pagenavigation_padding' ) ) );
		$css['global'][ capture_implode( $pagination_class ) ]['min-width']          = Capture_Sanitize::size( capture_get_settings( 'mts_pagenavigation_width' ) . 'px' );
		$css['global'][ capture_implode( $pagination_class_active ) ]['min-width']   = Capture_Sanitize::size( capture_get_settings( 'mts_pagenavigation_width' ) . 'px' );
		$css['global'][ capture_implode( $pagination_class ) ]['line-height']        = Capture_Sanitize::size( capture_get_settings( 'mts_pagenavigation_height' ) . 'px' );
		$css['global'][ capture_implode( $pagination_class_active ) ]['line-height'] = Capture_Sanitize::size( capture_get_settings( 'mts_pagenavigation_height' ) . 'px' );
		// Pagination border.
		$pagination_border = Capture_Sanitize::border( capture_get_settings( 'pagenavigation_border' ) );
		$css['global'][ capture_implode( $pagination_class ) ][ $pagination_border ['direction'] ] = $pagination_border ['value'];
		$pagination_hover_border = Capture_Sanitize::border( capture_get_settings( 'pagenavigation_hover_border' ) );
		$css['global'][ capture_implode( $pagination_class_active ) ][ $pagination_hover_border ['direction'] ] = $pagination_hover_border ['value'];
		$css['global'][ capture_implode( $pagination_class ) ]['border-radius']                                 = Capture_Sanitize::size( capture_get_settings( 'mts_pagenavigation_border_radius' ) . 'px' );
		$css['global'][ capture_implode( $pagination_class_active ) ]['border-radius']                          = Capture_Sanitize::size( capture_get_settings( 'mts_pagenavigation_border_radius' ) . 'px' );
	} else {
		$css['global'][ capture_implode( $pagination_class ) ]['background-color']        = Capture_Sanitize::color( capture_get_settings( 'load_more_bgcolor' ) );
		$css['global'][ capture_implode( $pagination_class_active ) ]['background-color'] = Capture_Sanitize::color( capture_get_settings( 'load_more_hover_bgcolor' ) );
		$css['global'][ capture_implode( $pagination_class ) ]['color']                   = Capture_Sanitize::color( capture_get_settings( 'load_more_color' ) );
		$css['global'][ capture_implode( $pagination_class_active ) ]['color']            = Capture_Sanitize::color( capture_get_settings( 'load_more_hover_color' ) );
		capture_merge_value( $css['global'][ capture_implode( array_merge( $pagination_class_active, $pagination_class ) ) ], Capture_Sanitize::padding( capture_get_settings( 'load_more_padding' ) ) );
		capture_merge_value( $css['global'][ capture_implode( array_merge( $pagination_class_active, $pagination_class ) ) ], Capture_Sanitize::margin( capture_get_settings( 'load_more_margin' ) ) );
		$css['global'][ capture_implode( $pagination_class_active ) ]['border-color'] = Capture_Sanitize::color( capture_get_settings( 'load_more_hover_bgcolor' ) );
		// Load More border.
		$load_more_border = Capture_Sanitize::border( capture_get_settings( 'load_more_border' ) );
		$css['global'][ capture_implode( $pagination_class ) ][ $load_more_border ['direction'] ] = $load_more_border ['value'];
		$css['global'][ capture_implode( $pagination_class ) ]['border-radius']                   = Capture_Sanitize::size( capture_get_settings( 'load_more_border_radius' ) . 'px' );
		$css['global'][ capture_implode( $pagination_class_active ) ]['border-radius']            = Capture_Sanitize::size( capture_get_settings( 'load_more_border_radius' ) . 'px' );
	}
	// Load more Alignment.
	$load_more_align = capture_get_settings( 'load_more_alignment' );
	if ( 'left' === $load_more_align ) :
		$css['global']['#load-posts']['text-align'] = 'left';
	elseif ( 'right' === $load_more_align ) :
		$css['global']['#load-posts']['text-align'] = 'right';
	elseif ( 'full' === $load_more_align ) :
		$css['global']['#load-posts a']['width'] = '100%';
	endif;
}

/**
 * Single
 *
 * @param array $css Array of dynamic CSS.
 */
function capture_single( &$css ) {

	// Single, Page and 404 Page Background.
	$page_classes = [
		'.single_post',
		'.page .article',
		'.error404 .article',
	];

	$css['global'][ capture_implode( $page_classes ) ] = Capture_Sanitize::background( capture_get_settings( 'single_background' ) );

	// Margin, Padding, Border and Box Shadow.
	capture_merge_value( $css['global'][ capture_implode( $page_classes ) ], Capture_Sanitize::margin( capture_get_settings( 'mts_single_styling_margin' ) ) );
	capture_merge_value( $css['global'][ capture_implode( $page_classes ) ], Capture_Sanitize::padding( capture_get_settings( 'mts_single_styling_padding' ) ) );

	// Full Header.
	$featured_image = '.single-full-header header';
	capture_merge_value( $css['global'][ $featured_image ], Capture_Sanitize::margin( capture_get_settings( 'featured_image_margin' ) ) );
	capture_merge_value( $css['global'][ $featured_image ], Capture_Sanitize::padding( capture_get_settings( 'featured_image_padding' ) ) );

	// Single border.
	$single_border = Capture_Sanitize::border( capture_get_settings( 'single_styling_border' ) );
	$css['global'][ capture_implode( $page_classes ) ][ $single_border ['direction'] ] = $single_border ['value'];

	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'mts_single_meta_info_font' ) ) );
	$single_meta_info_class = [
		'.single_post .post-info > span:after',
		'.single-full-header .post-info > span:after',
	];
	$single_meta_info_font  = capture_get_settings( 'mts_single_meta_info_font' );
	$css['global'][ capture_implode( $single_meta_info_class ) ]['background-color'] = Capture_Sanitize::color( $single_meta_info_font['color'] );
	// Tags.
	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'tags_social_heading' ) ) );
	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'tags_social_font' ) ) );
	$tags = '.social-tags';
	// Settings.
	$css['global'][ $tags ] = Capture_Sanitize::background( capture_get_settings( 'tags_social_background' ) );
	capture_merge_value( $css['global'][ $tags ], Capture_Sanitize::margin( capture_get_settings( 'tags_social_margin' ) ) );
	capture_merge_value( $css['global'][ $tags ], Capture_Sanitize::padding( capture_get_settings( 'tags_social_padding' ) ) );
	capture_merge_value( $css['global'][ $tags ], Capture_Sanitize::padding( capture_get_settings( 'tags_social_padding' ) ) );
	$css['global'][ $tags ]['border-color']             = Capture_Sanitize::color( capture_get_settings( 'tags_social_border_color' ) );
	$css['global']['.social-tags:before']['background'] = Capture_Sanitize::color( capture_get_settings( 'tags_social_border_color' ) );
	if ( ! capture_get_settings( 'tags_social_border' ) ) :
		$css['global'][ $tags ]['border']                = 'none!important';
		$css['global']['body .social-tags:before']['display'] = 'none!important';
	endif;
	// Related Posts.
	$related_class = '.related-posts';
	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'related_posts_meta_font' ) ) );
	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'related_posts_font' ) ) );
	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'related_posts_font' ) ) );
	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'related_posts_text_font' ) ) );
	$css['global'][ $related_class ] = Capture_Sanitize::background( capture_get_settings( 'related_posts_background' ) );
	capture_merge_value( $css['global'][ $related_class ], Capture_Sanitize::margin( capture_get_settings( 'related_posts_margin' ) ) );
	capture_merge_value( $css['global'][ $related_class ], Capture_Sanitize::padding( capture_get_settings( 'related_posts_padding' ) ) );

	$related_posts_border = Capture_Sanitize::border( capture_get_settings( 'related_posts_border' ) );
	$css['global'][ $related_class ][ $related_posts_border ['direction'] ] = $related_posts_border ['value'];
	// Related Read More.
	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'related_readmore_font' ) ) );
	$related_post_class      = '.related-posts .latestPost';
	$related_readmore_border = Capture_Sanitize::border( capture_get_settings( 'related_readmore_border' ) );
	$css['global'][ $related_post_class . ' .readMore a' ][ $related_readmore_border ['direction'] ] = $related_readmore_border['value'];
	capture_merge_value( $css['global'][ $related_post_class . ' .readMore a' ], Capture_Sanitize::padding( capture_get_settings( 'related_readmore_btn_padding' ) ) );
	// Color Options.
	$css['global'][ $related_post_class . ' .readMore a' ]['background']         = Capture_Sanitize::color( capture_get_settings( 'related_readmore_bg_color' ) );
	$css['global'][ $related_post_class . ' .readMore a:hover' ]['background']   = Capture_Sanitize::color( capture_get_settings( 'related_readmore_bg_hover_color' ) );
	$css['global'][ $related_post_class . ' .readMore a:hover' ]['color']        = Capture_Sanitize::color( capture_get_settings( 'related_readmore_hover_color' ) );
	$css['global'][ $related_post_class . ' .readMore a:hover' ]['border-color'] = Capture_Sanitize::color( capture_get_settings( 'related_readmore_border_hover_color' ) );
	$related_meta_info_class = '.related-posts .latestPost .post-info > span:after';
	$related_posts_meta_font = capture_get_settings( 'related_posts_meta_font' );
	// Related Meta Info.
	$css['global'][ $related_meta_info_class ]['background-color'] = Capture_Sanitize::color( $related_posts_meta_font['color'] );
	// Related Post Alignment.
	if ( 'default' === capture_get_settings( 'related_posts_layouts' ) ) :
		$related_alignment = capture_get_settings( 'related_post_alignment' );
		if ( 'center' === $related_alignment ) :
			$css['global'][ $related_post_class ]['text-align'] = 'center';
		endif;
		if ( 'right' === $related_alignment ) :
			$css['global'][ $related_post_class ]['text-align'] = 'right';
		endif;
	endif;
	// Subscribe Box.
	$css['global']['.single-subscribe .widget.wp_subscribe'] = Capture_Sanitize::background( capture_get_settings( 'single_subscribe_background' ) );
	capture_merge_value( $css['global']['.single-subscribe .widget.wp_subscribe'], Capture_Sanitize::margin( capture_get_settings( 'single_subscribe_margin' ) ) );
	capture_merge_value( $css['global']['.single-subscribe .widget.wp_subscribe'], Capture_Sanitize::padding( capture_get_settings( 'single_subscribe_padding' ) ) );
	$css['global']['.single-subscribe .widget.wp_subscribe']['border-radius'] = Capture_Sanitize::size( capture_get_settings( 'single_subscribe_border_radius' ) . 'px' );

	// Subscribe border.
	$subscribe_border = Capture_Sanitize::border( capture_get_settings( 'single_subscribe_border' ) );
	$css['global']['.single-subscribe .widget.wp_subscribe'][ $subscribe_border ['direction'] ] = $subscribe_border ['value'];

	// Subscribe Box Input fields.
	$subscribe_input_class = [
		'.single-subscribe #wp-subscribe input.email-field',
		'.single-subscribe #wp-subscribe input.name-field',
	];
	$css['global'][ capture_implode( $subscribe_input_class ) ]['height']        = Capture_Sanitize::size( capture_get_settings( 'single_subscribe_input_height' ) . 'px' );
	$css['global'][ capture_implode( $subscribe_input_class ) ]['border-radius'] = Capture_Sanitize::size( capture_get_settings( 'single_subscribe_input_border_radius' ) . 'px' );
	// Submit Class.
	$subscribe_single_submit = '.single-subscribe .widget #wp-subscribe input.submit';
	// Submit Button.
	$css['global'][ $subscribe_single_submit ]['height']      = Capture_Sanitize::size( capture_get_settings( 'single_subscribe_submit_height' ) . 'px' );
	$css['global'][ $subscribe_single_submit ]['line-height'] = Capture_Sanitize::size( capture_get_settings( 'single_subscribe_submit_height' ) . 'px' );
	// Subscribe Box Input border.
	$subscribe_box_input_border = Capture_Sanitize::border( capture_get_settings( 'single_subscribe_input_border' ) );
	$css['global'][ capture_implode( $subscribe_input_class ) ][ $subscribe_box_input_border ['direction'] ] = $subscribe_box_input_border ['value'];
	// Subscribe Box Submit button.
	$css['global'][ $subscribe_single_submit ]['background']    = Capture_Sanitize::color( capture_get_settings( 'single_subscribe_submit_backgroud' ) );
	$css['global'][ $subscribe_single_submit ]['border-radius'] = Capture_Sanitize::size( capture_get_settings( 'single_subscribe_submit_border_radius' ) . 'px' );

	// Subscribe Box Submit border.
	$subscribe_box_submit_border = Capture_Sanitize::border( capture_get_settings( 'single_subscribe_submit_border' ) );
	$css['global']['.single-subscribe .widget #wp-subscribe input.submit'][ $subscribe_box_submit_border ['direction'] ] = $subscribe_box_submit_border ['value'];

	capture_merge_value( $css['global']['.single-subscribe .widget #wp-subscribe input.submit'], Capture_Sanitize::padding( capture_get_settings( 'single_subscribe_submit_padding' ) ) );

	// Author Box.
	$postauthor = '.postauthor';
	// Author Box Settings.
	$css['global'][ $postauthor ] = Capture_Sanitize::background( capture_get_settings( 'authorbox_background' ) );
	capture_merge_value( $css['global'][ $postauthor ], Capture_Sanitize::margin( capture_get_settings( 'authorbox_margin' ) ) );
	capture_merge_value( $css['global'][ $postauthor ], Capture_Sanitize::padding( capture_get_settings( 'authorbox_padding' ) ) );
	$css['global'][ $postauthor ]['border-radius'] = Capture_Sanitize::size( capture_get_settings( 'authorbox_border_radius' ) . 'px' );
	// Border.
	$authorbox_border = Capture_Sanitize::border( capture_get_settings( 'authorbox_border' ) );
	$css['global'][ $postauthor ][ $authorbox_border ['direction'] ] = $authorbox_border ['value'];
	// Author image.
	capture_merge_value( $css['global'][ $postauthor . ' img' ], Capture_Sanitize::margin( capture_get_settings( 'single_author_image_margin' ) ) );
	$css['global'][ $postauthor . ' img' ]['border-radius'] = Capture_Sanitize::size( capture_get_settings( 'single_author_image_border_radius' ) . 'px' );
	// Author Social.
	$author_social = '.author-social a';
	capture_merge_value( $css['global'][ $author_social ], Capture_Sanitize::margin( capture_get_settings( 'author_social_margin' ) ) );
	capture_merge_value( $css['global'][ $author_social ], Capture_Sanitize::padding( capture_get_settings( 'author_social_padding' ) ) );
	$css['global'][ $author_social ] ['background']         = Capture_Sanitize::color( capture_get_settings( 'author_social_background' ) );
	$css['global']['.author-social a:hover'] ['background'] = Capture_Sanitize::color( capture_get_settings( 'author_social_hover_background' ) );
	$css['global'][ $author_social ]['color']               = Capture_Sanitize::color( capture_get_settings( 'author_social_color' ) );
	$css['global']['.author-social a:hover']['color']       = Capture_Sanitize::color( capture_get_settings( 'author_social_hover_color' ) );
	$css['global'][ $author_social ]['border-radius']       = Capture_Sanitize::size( capture_get_settings( 'author_social_border_radius' ) . 'px' );

	// Single Page titles Styling.
	$titles_align = capture_get_settings( 'single_title_alignment' );

	$titles_align_class = [
		'.comment-title',
		'#respond',
		'.related-posts-title',
	];
	$titles_class       = [
		'#respond h4',
		'.total-comments',
		'.related-posts h4',
	];

	$css['global'][ capture_implode( $titles_class ) ] = Capture_Sanitize::background( capture_get_settings( 'single_title_background' ) );
	capture_merge_value( $css['global'][ capture_implode( $titles_class ) ], Capture_Sanitize::padding( capture_get_settings( 'single_title_padding' ) ) );
	// Single title border.
	$single_titles_border = Capture_Sanitize::border( capture_get_settings( 'single_title_border' ) );
	$css['global'][ capture_implode( $titles_class ) ][ $single_titles_border ['direction'] ] = $single_titles_border ['value'];

	if ( 'left' === $titles_align ) :
		$css['global'][ capture_implode( $titles_class ) ]['display'] = 'inline-block';
	elseif ( 'center' === $titles_align ) :
		$css['global'][ capture_implode( $titles_align_class ) ]['text-align'] = 'center';
		$css['global'][ capture_implode( $titles_class ) ]['display']          = 'inline-block';
	elseif ( 'right' === $titles_align ) :
		$css['global'][ capture_implode( $titles_align_class ) ]['text-align'] = 'right';
		$css['global'][ capture_implode( $titles_class ) ]['display']          = 'inline-block';
	endif;

	// Comments.
	// Margin and Padding.

	// Author Comment.
	$css['global']['#comments li.bypostauthor .comment-list']['background-color'] = Capture_Sanitize::color( capture_get_settings( 'author_comment_bg' ) );

	// Typography.
	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'comments_title_font' ) ) );
	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'comments_meta_font' ) ) );
	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'comments_text_font' ) ) );
	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'reply_font' ) ) );

}

/**
 * Footer Social & Nav
 *
 * @param array $css Array of dynamic CSS.
 */
function capture_single_photos_cpt( &$css ) {
	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'single_photo_title_font' ) ) );
	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'single_photo_meta_info_font' ) ) );
	$single_photo_meta_class     = [
		'.single_post .post-info > span:after',
		'.single-full-header.single-cpt-photo .post-info > span:after',
	];
	$single_photo_meta_info_font = capture_get_settings( 'single_photo_meta_info_font' );
	$css['global'][ capture_implode( $single_photo_meta_class ) ]['background-color'] = Capture_Sanitize::color( $single_photo_meta_info_font['color'] );
	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'single_photo_nextprev_font' ) ) );
	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'model_title_font' ) ) );
	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'model_desc_font' ) ) );
	$single_photo_nextprev_font = capture_get_settings( 'single_photo_nextprev_font' );
	// svg stroke.
	$css['global']['.prev-next path']['stroke'] = Capture_Sanitize::color( $single_photo_nextprev_font['color'] );
	// Prev Next.
	if ( ! capture_get_settings( 'header_single_prev_next' ) ) :
		$header_single_prev_next = '.single-header header';
		// header css.
		$css['global'][ $header_single_prev_next ]['justify-content']       = 'center';
		$css['global'][ $header_single_prev_next ]['grid-template-columns'] = '80%';
		// Responsive screen.
		$css['@media screen and (max-width: 1024px)'][ $header_single_prev_next ]['grid-template-columns'] = '100%';
	endif;
	if ( ! capture_get_settings( 'header_photos_prev_next' ) ) :
		$header_photos_prev_next = '.single-cpt-photo header';
		// header css.
		$css['global'][ $header_photos_prev_next ]['justify-content']       = 'center';
		$css['global'][ $header_photos_prev_next ]['grid-template-columns'] = '80%';
		// Responsive screen. 
		$css['@media screen and (max-width: 1024px)'][ $header_photos_prev_next ]['grid-template-columns'] = '100%';
	endif;
	// Photo Info.
	$lists = get_post_meta( get_the_ID(), 'photo_info_group', true );
	if ( empty( $lists ) ) {
		$css['global']['.photos-single-left']['width'] = '100%';
	}
}

/**
 * Footer
 *
 * @param array $css Array of dynamic CSS.
 */
function capture_footer( &$css ) {
	// Footer.
	capture_merge_value( $css['global']['#site-footer'], Capture_Sanitize::margin( capture_get_settings( 'mts_top_footer_margin' ) ) );
	capture_merge_value( $css['global']['#site-footer .footer-widgets'], Capture_Sanitize::padding( capture_get_settings( 'mts_top_footer_padding' ) ) );
	$mts_top_footer_border = Capture_Sanitize::border( capture_get_settings( 'mts_top_footer_border' ) );
	$css['global']['#site-footer:after'][ $mts_top_footer_border ['direction'] ] = $mts_top_footer_border ['value'];
	// Footer Social icons.
	if ( ! empty( capture_get_settings( 'mts_footer_social_share' ) ) && ! empty( capture_get_settings( 'mts_footer_social' ) ) && is_array( capture_get_settings( 'mts_footer_social' ) ) ) :
		$footer_icons = capture_get_settings( 'mts_footer_social' );
		foreach ( $footer_icons as $footer_icon ) :
			$css['global'][ '.footer-social-icons a.footer-' . $footer_icon['mts_footer_icon'] ]['background-color']            = Capture_Sanitize::color( $footer_icon['mts_footer_icon_bgcolor'] );
			$css['global'][ '.footer-social-icons a.footer-' . $footer_icon['mts_footer_icon'] . ':hover' ]['background-color'] = Capture_Sanitize::color( $footer_icon['mts_footer_icon_hover_bgcolor'] );
			$css['global'][ '.footer-social-icons a.footer-' . $footer_icon['mts_footer_icon'] ]['color']                       = Capture_Sanitize::color( $footer_icon['mts_footer_icon_color'] );
			$css['global'][ '.footer-social-icons a.footer-' . $footer_icon['mts_footer_icon'] . ':hover' ]['color']            = Capture_Sanitize::color( $footer_icon['mts_footer_icon_hover_color'] );

			capture_merge_value( $css['global'][ '.footer-social-icons a.footer-' . $footer_icon['mts_footer_icon'] ], Capture_Sanitize::margin( $footer_icon['mts_footer_icon_margin'] ) );
			capture_merge_value( $css['global'][ '.footer-social-icons a.footer-' . $footer_icon['mts_footer_icon'] ], Capture_Sanitize::padding( $footer_icon['mts_footer_icon_padding'] ) );
			$css['global'][ '.footer-social-icons a.footer-' . $footer_icon['mts_footer_icon'] ]['border-radius'] = Capture_Sanitize::size( $footer_icon['mts_footer_icon_border_radius'] . 'px' );
		endforeach;
	endif;
	// Copyrights Nav menu item.
	capture_merge_value( $css['global']['nav.footer-nav li a'], Capture_Sanitize::margin( capture_get_settings( 'footer_menu_item_margin' ) ) );
	capture_merge_value( $css['global']['nav.footer-nav .footer-separator'], Capture_Sanitize::margin( capture_get_settings( 'footer_nav_separator_margin' ) ) );
	$css['global']['nav.footer-nav .footer-separator']['color'] = Capture_Sanitize::color( capture_get_settings( 'footer_nav_separator_color' ) );
	// Subscribe Box.
	$css['global']['#site-footer .widget.wp_subscribe'] = Capture_Sanitize::background( capture_get_settings( 'footer_subscribe_widget_background' ) );
	capture_merge_value( $css['global']['#site-footer .widget.wp_subscribe'], Capture_Sanitize::padding( capture_get_settings( 'footer_subscribe_widget_padding' ) ) );
	$footer_subscribe_border = Capture_Sanitize::border( capture_get_settings( 'footer_subscribe_widget_border' ) );
	$css['global']['#site-footer .widget.wp_subscribe'][ $footer_subscribe_border ['direction'] ] = $footer_subscribe_border ['value'];
	// Subscribe Box Submit button.
	$css['global']['#site-footer .widget #wp-subscribe input.submit']['background'] = Capture_Sanitize::color( capture_get_settings( 'footer_subscribe_widget_submit_backgroud' ) );
	// Footer title.
	$footer_title                   = '#site-footer .widget h3';
	$css['global'][ $footer_title ] = Capture_Sanitize::background( capture_get_settings( 'footer_title_styling_background' ) );
	capture_merge_value( $css['global'][ $footer_title ], Capture_Sanitize::padding( capture_get_settings( 'footer_title_styling_padding' ) ) );
	capture_merge_value( $css['global'][ $footer_title ], Capture_Sanitize::margin( capture_get_settings( 'footer_title_styling_margin' ) ) );
	// Footer Title border.
	$footer_title_border = Capture_Sanitize::border( capture_get_settings( 'footer_widget_title_border' ) );
	$css['global'][ $footer_title ][ $footer_title_border['direction'] ] = $footer_title_border['value'];
	$footer_meta_info_class = '#site-footer .post-info > span:after';
	$footer_meta_info_font  = capture_get_settings( 'top_footer_meta_font' );
	// Footer meta divider.
	$css['global'][ $footer_meta_info_class ]['background-color'] = Capture_Sanitize::color( $footer_meta_info_font['color'] );
	// Footer bullet styling.
	$footer_bullet = [
		'#site-footer .widget.widget_categories li:after',
		'#site-footer .widget.widget_archive li:after',
		'#site-footer .widget.widget_pages li:after',
		'#site-footer .widget.widget_meta li:after',
		'#site-footer .widget.widget_recent_comments li:after',
		'#site-footer .widget.widget_recent_entries li:after',
		'#site-footer .widget.widget_rss li:after',
		'#site-footer .widget.widget_nav_menu li:after',
	];
	// Links bullet.
	$footer_links_widgets = capture_get_settings( 'footer_links_widgets' );
	$css['global'][ capture_implode( $footer_bullet ) ]['background-color'] = Capture_Sanitize::color( $footer_links_widgets['color'] );
}

/**
 * Footer Social & Nav
 *
 * @param array $css Array of dynamic CSS.
 */
function capture_social_nav_footer( &$css ) {
	// Footer Social & Nav.
	$footer_social_nav = '.footer-social-nav-section';
	capture_merge_value( $css['global'][ $footer_social_nav ], Capture_Sanitize::margin( capture_get_settings( 'footer_social_nav_margin' ) ) );
	capture_merge_value( $css['global'][ $footer_social_nav ], Capture_Sanitize::padding( capture_get_settings( 'footer_social_nav_padding' ) ) );
	capture_merge_value( $css['global'][ $footer_social_nav ], Capture_Sanitize::background( capture_get_settings( 'footer_social_nav_background' ) ) );
	$footer_social_nav_border = Capture_Sanitize::border( capture_get_settings( 'footer_social_nav_border' ) );
	$css['global'][ $footer_social_nav ][ $footer_social_nav_border ['direction'] ] = $footer_social_nav_border ['value'];
	$footer_nav_section      = capture_get_settings( 'footer_nav_section' );
	$mts_footer_social_share = capture_get_settings( 'mts_footer_social_share' );
	if ( ! $footer_nav_section ) {
		$css['global']['.footer-social-icons']['flex'] = 'inherit';
		// content.
		$css['global']['.footer-social-nav-section .container']['justify-content'] = 'center';
	}
	if ( ! $mts_footer_social_share ) {
		$css['global']['nav.footer-nav']['flex'] = 'inherit';
		// content.
		$css['global']['.footer-social-nav-section .container']['justify-content'] = 'center';
	}
}

/**
 * Copyrights
 *
 * @param array $css Array of dynamic CSS.
 */
function capture_copyrights( &$css ) {
	// Copyrights.
	$copyrights = '.copyrights';
	capture_merge_value( $css['global'][ $copyrights ], Capture_Sanitize::margin( capture_get_settings( 'mts_copyrights_margin' ) ) );
	capture_merge_value( $css['global'][ $copyrights ], Capture_Sanitize::padding( capture_get_settings( 'mts_copyrights_padding' ) ) );
	capture_merge_value( $css['global'][ $copyrights ], Capture_Sanitize::background( capture_get_settings( 'mts_copyrights_background' ) ) );
	$copyrights_border = Capture_Sanitize::border( capture_get_settings( 'copyrights_border' ) );
	$css['global'][ $copyrights ][ $copyrights_border ['direction'] ] = $copyrights_border ['value'];
}

/**
 * Archive
 *
 * @param array $css Array of dynamic CSS.
 */
function capture_archive_post( &$css ) {

	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'archive_post_title_font' ) ) );
	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'archive_post_excerpt_font' ) ) );
	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'archive_meta_info_font' ) ) );
	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'archive_readmore_font' ) ) );
	$single_meta_info_class = [
		'.archive .post-info > span:after',
		'.search .post-info > span:after',
	];
	$single_meta_info_font  = capture_get_settings( 'mts_single_meta_info_font' );
	$css['global'][ capture_implode( $single_meta_info_class ) ]['background-color'] = Capture_Sanitize::color( $single_meta_info_font['color'] );
	// Archive Read More.
	$archive_readmore_class = [
		'.archive .latestPost .readMore a',
		'.search .latestPost .readMore a',
	];

	$archive_readmore_hover_class = [
		'.archive .latestPost .readMore a:hover',
		'.search .latestPost .readMore a:hover',
	];

	$archive_readmore_border = Capture_Sanitize::border( capture_get_settings( 'archive_readmore_border' ) );
	$css['global'][ capture_implode( $archive_readmore_class ) ][ $archive_readmore_border ['direction'] ] = $archive_readmore_border['value'];
	capture_merge_value( $css['global'][ capture_implode( $archive_readmore_class ) ], Capture_Sanitize::padding( capture_get_settings( 'archive_readmore_btn_padding' ) ) );
	// Color Options.
	$css['global'][ capture_implode( $archive_readmore_class ) ]['background']         = Capture_Sanitize::color( capture_get_settings( 'archive_readmore_bg_color' ) );
	$css['global'][ capture_implode( $archive_readmore_hover_class ) ]['background']   = Capture_Sanitize::color( capture_get_settings( 'archive_readmore_bg_hover_color' ) );
	$css['global'][ capture_implode( $archive_readmore_hover_class ) ]['color']        = Capture_Sanitize::color( capture_get_settings( 'archive_readmore_hover_color' ) );
	$css['global'][ capture_implode( $archive_readmore_hover_class ) ]['border-color'] = Capture_Sanitize::color( capture_get_settings( 'archive_readmore_border_hover_color' ) );
}

/**
 * Misc
 *
 * @param array $css Array of dynamic CSS.
 */
function capture_misc_css( &$css ) {

	// Show Logo.
	$show_logo = capture_get_settings( 'hide_logo' );

	if ( 0 === $show_logo ) {
		$css['global']['.logo-wrap']['display'] = 'none';
	}

	$move_to_top = '#move-to-top';

	// Back to top.
	$css['global'][ $move_to_top ]['background-color'] = Capture_Sanitize::color( capture_get_settings( 'top_button_background' ) );

	$css['global']['#move-to-top:hover']['background-color'] = Capture_Sanitize::color( capture_get_settings( 'top_button_background_hover' ) );

	// Border.
	$top_button_border = Capture_Sanitize::border( capture_get_settings( 'top_button_border' ) );
	$css['global'][ $move_to_top ][ $top_button_border ['direction'] ] = $top_button_border ['value'];
	// Font-size, Padding and Position.
	$css['global']['#move-to-top .fa']['font-size'] = Capture_Sanitize::size( capture_get_settings( 'top_button_font_size' ) . 'px' );
	$css['global']['#move-to-top .fa']['width']     = Capture_Sanitize::size( capture_get_settings( 'top_button_font_size' ) . 'px' );
	capture_merge_value( $css['global'][ $move_to_top ], Capture_Sanitize::padding( capture_get_settings( 'top_button_padding' ) ) );
	$top_button_position = capture_get_settings( 'top_button_position' );
	foreach ( $top_button_position as $key => $position ) {
		$css['global'][ $move_to_top ][ $key ] = $position;
	}
	// Border-radius.
	$css['global'][ $move_to_top ]['border-radius'] = Capture_Sanitize::size( capture_get_settings( 'top_button_border_radius' ) . 'px' );
	// Colors.
	$css['global'][ $move_to_top ]['color']       = Capture_Sanitize::color( capture_get_settings( 'top_button_color' ) );
	$css['global']['#move-to-top:hover']['color'] = Capture_Sanitize::color( capture_get_settings( 'top_button_color_hover' ) );

	$css['global']['#move-to-top:hover']['border-color'] = Capture_Sanitize::color( capture_get_settings( 'top_button_background_hover' ) );

	// Full width Related Posts.
	if ( 'full' === capture_get_settings( 'related_posts_position' ) ) {
		$css['global']['.single .article']['margin-bottom'] = '0px';
	}

}

/**
 * Photos CPT
 *
 * @param array $css Array of dynamic CSS.
 */
function capture_custom_posts( &$css ) {
	// Photos CPT Typography.
	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'photo_title_font' ) ) );
	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'photo_popup_counter_font' ) ) );
	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'photo_readmore_font' ) ) );
	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'photo_like_font' ) ) );
	capture_map_css_selectors( $css['global'], Capture_Sanitize::typography( capture_get_settings( 'photo_like_hover_font' ) ) );
	$css['global']['.post-hover .featured-thumbnail:before']['background'] = Capture_Sanitize::color( capture_get_settings( 'photos_overlay' ) );
}
