<?php
/**
 * Template functions that the framework or themes may use.
 */

if ( ! function_exists( 'capture_logo' ) ) {
	/**
	 * Site Logo
	 *
	 * @param array $args arguments.
	 * @param array $loc location.
	 * @return void
	 */
	function capture_logo( $args = [], $loc = 'mts' ) {

		$capture_logo = wp_get_attachment_url( capture_get_settings( $loc . '_logo' ) );

		$h_tag     = 'h2';
		$logo_type = 'text-logo';

		if ( is_page_template( 'page-home.php' ) || is_home() ) {
			$h_tag = 'h1';
		}

		if ( ! empty( $capture_logo ) ) {
			$logo_type = 'image-logo';
		}

		$defaults = [
			'logo'   => $capture_logo,
			'url'    => esc_url( home_url() ),
			'title'  => get_bloginfo( 'name' ),
			'before' => '<' . $h_tag . ' id="logo" class="' . $logo_type . ' clearfix" itemprop="headline">',
			'after'  => '</' . $h_tag . '>',
		];

		$args = wp_parse_args( $args, $defaults );

		$output = $args['logo'] ? sprintf( '<img src="' . $args['logo'] . '" alt="' . esc_attr( $args['title'] ) . '">' ) : $args['title'];
		$output = sprintf( '<a href="%1$s">%2$s</a>', $args['url'], $output );

		echo wp_kses_post( $args['before'] ) . $output . wp_kses_post( $args['after'] );
	}
}

if ( ! function_exists( 'capture_single_featured_image_effect' ) ) {
	/**
	 * Single Post Header Layout type (Parallax or Zoomout) *
	 */
	function capture_single_featured_image_effect() {

		$header_animation = capture_get_post_header_effect();

		if ( has_post_thumbnail() && $header_animation ) {
			echo '<div class="single-featured-image">';
			echo '<div class="container">';
			if ( 'parallax' === $header_animation ) {
				echo '<div id="parallax" style="background-image: url(' . get_the_post_thumbnail_url( get_the_ID(), 'capture-single-featured' ) . ');"></div>';
			} elseif ( 'zoomout' === $header_animation ) {
				echo '<div id="zoom-out-effect"><div id="zoom-out-bg" style="background-image: url(' . get_the_post_thumbnail_url( get_the_ID(), 'full' ) . ');"></div></div>';
			}
			echo '</div>';
			echo '</div>';
		}

	}
}

if ( ! function_exists( 'capture_post_tags' ) ) {
	/**
	 * Display capture_post_tags()
	 *
	 * @param string $before before.
	 * @param string $sep seprator.
	 * @param string $after after.
	 * @param string $tax taxnomies.
	 */
	function capture_post_tags( $before = '', $sep = ', ', $after = '</div>', $tax = 'post_tag' ) {
		if ( empty( $before ) ) {
			$before = '<div class="tags">' . esc_html__( 'Tags', 'capture' );
		}
		$tags = get_the_terms( get_the_ID(), $tax );
		if ( empty( $tags ) || is_wp_error( $tags ) ) {
			return;
		}
		$tag_links = [];
		foreach ( $tags as $tag ) {
			$link        = get_term_link( $tag->term_id, $tax );
			$tag_links[] = '<a href="' . esc_url( $link ) . '" rel="tag">' . $tag->name . '</a>';
		}
		echo $before . join( $sep, $tag_links ) . $after;
	}
}

/**
 * Returns true if a blog has more than 1 category.
 *
 * @return bool
 */
if ( ! function_exists( 'capture_categorized_blog' ) ) {
	function capture_categorized_blog() {
		$category_count = get_transient( 'capture_categories' );

		if ( false === $category_count ) {
			// Create an array of all the categories that are attached to posts.
			$categories = get_categories( [
				'fields'     => 'ids',
				'hide_empty' => 1,
				// We only need to know if there is more than one category.
				'number'     => 2,
			] );

			// Count the number of categories that are attached to the posts.
			$category_count = count( $categories );

			set_transient( 'capture_categories', $category_count );
		}

		return $category_count > 1;
	}
}

/**
 * Display the post info block.
 *
 * @param string $section
 */
if ( ! function_exists( 'capture_the_post_meta' ) ) {
	function capture_the_post_meta( $section = 'home', $groupid = '' ) {

		$enabled_metas = capture_get_settings( 'mts_' . $section . '_headline_meta_info' . $groupid );

		$enabled_metas = isset( $enabled_metas['enabled'] ) ? $enabled_metas['enabled'] : [];

		if ( ! empty( $enabled_metas ) ) :
			?>
			<div class="post-info">
				<?php
				foreach ( $enabled_metas as $key => $title ) {

					$pagename = 'mts';
					$suffix   = '_';

					$author_icon   = ( capture_get_settings( $pagename . '_meta_info_author_icon' . $suffix . $groupid ) ) ? '<i class="fa fa-' . capture_get_settings( $pagename . '_meta_info_author_icon' . $suffix . $groupid ) . '"></i>' : '';
					$date_icon     = ( capture_get_settings( $pagename . '_meta_info_date_icon' . $suffix . $groupid ) ) ? '<i class="fa fa-' . capture_get_settings( $pagename . '_meta_info_date_icon' . $suffix . $groupid ) . '"></i>' : '';
					$category_icon = ( capture_get_settings( $pagename . '_meta_info_category_icon' . $suffix . $groupid ) ) ? '<i class="fa fa-' . capture_get_settings( $pagename . '_meta_info_category_icon' . $suffix . $groupid ) . '"></i>' : '';
					$comment_icon  = ( capture_get_settings( $pagename . '_meta_info_comment_icon' . $suffix . $groupid ) ) ? '<i class="fa fa-' . capture_get_settings( $pagename . '_meta_info_comment_icon' . $suffix . $groupid ) . '"></i>' : '';

					switch ( $key ) {

						case 'author':
							printf( '<span class="theauthor">%1$s<span>%2$s</span></span>', $author_icon, get_the_author_posts_link() );
							break;

						case 'date':
							printf( '<span class="thetime date updated">%1$s<span>%2$s</span></span>', $date_icon, get_the_time( get_option( 'date_format' ) ) );
							break;

						case 'category':
							if ( is_singular( 'photos' ) ) {
								printf( '<span class="thecategory">%1$s%2$s</span>', $category_icon, capture_photos_category( ', ' ) );
							} else {
								printf( '<span class="thecategory">%1$s%2$s</span>', $category_icon, capture_get_the_category( ', ' ) );
							}
							break;

						case 'comment':
							printf( '<span class="thecomment">%1$s<a href="%2$s" itemprop="interactionCount">%3$s</a></span>', $comment_icon, esc_url( get_comments_link() ), get_comments_number_text() );
							break;
					}
				}
				?>
			</div>
			<?php
		endif;
	}
}

if ( ! function_exists( 'capture_get_the_category' ) ) {
	/**
	 * Display capture-compliant the_category()
	 *
	 * @param string $separator separator for categories.
	 */
	function capture_get_the_category( $separator = ', ' ) {
		$categories = get_the_category();

		if ( empty( $categories ) ) {
			return;
		}

		global $wp_rewrite;

		$links = [];
		$rel   = ( is_object( $wp_rewrite ) && $wp_rewrite->using_permalinks() ) ? 'rel="category tag"' : 'rel="category"';

		foreach ( $categories as $category ) {

			$links[] = sprintf(
				'<a href="%1$s" title="%2$s" %3$s>%4$s</a>',
				esc_url( get_category_link( $category->term_id ) ),
				// translators: category name.
				sprintf( esc_html__( 'View all posts in %s', 'capture' ), esc_attr( $category->name ) ),
				$rel,
				esc_html( $category->name )
			);
		}

		return join( $separator, $links );
	}
}

if ( ! function_exists( 'capture_photos_category' ) ) {
	/**
	 * Display capture-compliant the_category()
	 *
	 * @param string $separator separator for categories.
	 */
	function capture_photos_category( $separator = ', ' ) {
		$terms = get_the_terms( get_the_ID(), 'photos_categories' );
		if ( empty( $terms ) ) {
			return;
		}
		global $wp_rewrite;

		$links = [];
		$rel   = ( is_object( $wp_rewrite ) && $wp_rewrite->using_permalinks() ) ? 'rel="category tag"' : 'rel="category"';
		foreach ( $terms as $term ) {

			$links[] = sprintf(
				'<a href="%1$s" title="%2$s" %3$s>%4$s</a>',
				esc_url( get_term_link( $term->term_id ) ),
				// translators: category name.
				sprintf( esc_html__( 'View all posts in %s', 'capture' ), esc_attr( $term->slug ) ),
				$rel,
				esc_html( $term->slug )
			);
		}

		return join( $separator, $links );
	}
}

if ( ! function_exists( 'capture_pagination' ) ) {
	/**
	 * Display the pagination.
	 *
	 * @param string $nav_type pagination
	 */
	function capture_pagination( $nav_type = '' ) {

		$args = Capture_Photos::get_photos_query_args();

		if ( is_tax( 'photos_categories' ) ) {

			$current_catname = get_queried_object();

			$new_args = [
				'tax_query' => [
					[
						'taxonomy' => 'photos_categories',
						'field'    => 'slug',
						'terms'    => $current_catname->slug,
					],
				],
			];

			$args = Capture_Photos::get_photos_query_args( $new_args );
		}

		$ph_query = new WP_Query( $args );

		if ( is_page_template( 'page-home.php' ) || is_post_type_archive( 'photos' ) || is_tax( 'photos_categories' ) ) {
			$GLOBALS['wp_query'] = $ph_query; // phpcs:ignore
		}

		if ( 1 === $GLOBALS['wp_query']->max_num_pages ) {
			return;
		}

		if ( 1 === $nav_type ) { // Numeric pagination.
			the_posts_pagination(
				[
					'mid_size'  => 3,
					'prev_text' => '<i class="fa fa-angle-left"></i>',
					'next_text' => '<i class="fa fa-angle-right"></i>',
				]
			);
		} else { // traditional or ajax pagination.
			?>
			<div class="pagination pagination-previous-next">
				<ul>
					<li class="nav-previous"><?php next_posts_link( '<i class="fa fa-angle-left"></i>' . esc_html__( 'Prev', 'capture' ) ); ?></li>
					<li class="nav-next"><?php previous_posts_link( esc_html__( 'Next', 'capture' ) . '<i class="fa fa-angle-right"></i>' ); ?></li>
				</ul>
			</div>
			<?php
		}
	}
}

if ( ! function_exists( 'capture_social_icons' ) ) {
	/**
	 * Display social icons
	 *
	 * @param array   $data header social icons.
	 * @param boolean $echo condition to check header social.
	 * @return html
	 */
	function capture_social_icons( $data = [], $echo = false ) {

		if ( empty( $data ) ) {
			return;
		}

		$out = '<div class="header-social-icons">';
		foreach ( $data as $item ) {
			$out .= sprintf(
				'<a href="%1$s" title="%2$s" class="header-%3$s" target="_blank"><span class="fa fa-%3$s"></span></a>',
				$item['header_icon_link'],
				$item['header_icon_title'],
				$item['header_icon']
			);
		}

		$out .= '</div>';

		if ( $echo ) {
			echo $out;
		} else {
			return $out;
		}
	}
}

if ( ! function_exists( 'capture_footer_social_icons' ) ) {
	/**
	 * Display social icons
	 *
	 * @param array   $data footer social icons.
	 * @param boolean $echo condition to check footer social.
	 * @return html
	 */
	function capture_footer_social_icons( $data = [], $echo = false ) {

		if ( empty( $data ) ) {
			return;
		}

		$out = '<div class="footer-social-icons">';
		foreach ( $data as $item ) {
			$out .= sprintf(
				'<a href="%1$s" title="%2$s" class="footer-%3$s" target="_blank"><span class="fa fa-%3$s"></span></a>',
				$item['mts_footer_icon_link'],
				$item['mts_footer_icon_title'],
				$item['mts_footer_icon']
			);
		}

		$out .= '</div>';

		if ( $echo ) {
			echo $out;
		} else {
			return $out;
		}
	}
}

/**
 * Create and show column for featured image in the post list of admin page
 * @param $post_id
 * @return string url
 */
if ( ! function_exists( 'capture_get_featured_image' ) ) {
	function capture_get_featured_image( $post_id ) {
		if ( $post_thumbnail_id = get_post_thumbnail_id( $post_id ) ) { // @codingStandardsIgnoreLine
			$post_thumbnail_img = wp_get_attachment_image_src( $post_thumbnail_id, 'capture-widgetfull' );
			return $post_thumbnail_img[0];
		}
	}
}

/**
 * Adds a `Featured Image` column header in the Post list of admin page
 *
 * @param array $defaults
 * @return array
 */
if ( ! function_exists( 'capture_columns_head' ) ) {
	function capture_columns_head( $defaults ) {
		if ( 'post' === get_post_type() ) {
			$defaults['featured_image'] = __( 'Featured Image', 'capture' );
		}

		return $defaults;
	}
}
add_filter( 'manage_posts_columns', 'capture_columns_head' );

/**
 * Adds a `Featured Image` column row value in the Post list of admin page
 *
 * @param string $column_name The name of the column to display.
 * @param int $post_id The ID of the current post.
 */
if ( ! function_exists( 'capture_columns_content' ) ) {
	function capture_columns_content( $column_name, $post_id ) {
		if ( 'featured_image' === $column_name ) {
			if ( $post_featured_image = capture_get_featured_image( $post_id ) ) { // @codingStandardsIgnoreLine
				echo '<img width="150" height="100" src="' . esc_url( $post_featured_image ) . '" />';
			}
		}
	}
}
add_action( 'manage_posts_custom_column', 'capture_columns_content', 10, 2 );

/**
 * Footer Widget Columns
 *
 * @return string
 */
if ( ! function_exists( 'capture_footer_widget_columns' ) ) {
	function capture_footer_widget_columns() {

		$footer_columns = intval( capture_get_settings( 'mts_top_footer_num' ) );

		if ( ! $footer_columns ) {
			return;
		}
		?>
		<div class="footer-widgets first-footer-widgets widgets-num-<?php echo esc_attr( $footer_columns ); ?>">
			<div class="container">
			<?php
			for ( $i = 1; $i <= $footer_columns; $i++ ) :
				$class = '';
				if ( $i === $footer_columns ) {
					$class = ' last';
				} elseif ( 1 === $i ) {
					$class = ' first';
				}
				?>
				<div class="f-widget f-widget-<?php echo esc_attr( $i ) . esc_attr( $class ); ?>">
					<?php dynamic_sidebar( 'footer-top-' . $i ); ?>
				</div>
			<?php endfor; ?>
			</div>
		</div><!--.first-footer-widgets-->

		<?php
	}
}

if ( ! function_exists( 'capture_footer_social_nav' ) ) {
	/**
	 * Footer Nav section
	 */
	function capture_footer_social_nav() {
		if ( capture_get_settings( 'footer_nav_section' ) ) :
			$footer_separator = capture_get_settings( 'footer_nav_separator_content' );
			$separator        = ( capture_get_settings( 'footer_nav_separator' ) ? '<span class="footer-separator">' . $footer_separator . '</span>' : '' );
			?>
			<nav class="footer-nav">
				<?php
				// Footer Navigation.
				if ( has_nav_menu( 'footer-menu' ) ) {
					wp_nav_menu(
						[
							'theme_location' => 'footer-menu',
							'menu_class'     => 'footer-menu clearfix',
							'container'      => '',
							'after'          => $separator,
							'walker'         => new capture_menu_walker(),
						]
					);
				}
				?>
			</nav>
			<?php
		endif;
	}
}

if ( ! function_exists( 'capture_footer_copyrights' ) ) {
	/**
	 * Copyrights section
	 */
	function capture_footer_copyrights() {
		$content = capture_get_settings( 'mts_copyrights' );
		$copyright_text = '<a href=" ' . esc_url( trailingslashit( home_url() ) ) . '" title=" ' . get_bloginfo( 'description' ) . '">' . get_bloginfo( 'name' ) . '</a> ' . __( 'Copyright', 'capture' ) . ' &copy; ' . date( 'Y' ) . '.';
		?>
		<div class="copyrights">
			<div class="container">

				<div class="row" id="copyright-note">
					<span><?php echo $copyright_text; ?></span>
					<div class="to-top"><?php echo $content; ?></div>
				</div>

			</div>
		</div>
		<?php
	}
}

/**
 * Capture display comments
 */
function capture_display_comments() {
	// If comments are open or we have at least one comment, load up the comment template.
	if ( comments_open() || 0 !== intval( get_comments_number() ) ) :
		comments_template();
	endif;
}

if ( ! function_exists( 'capture_comments' ) ) {
	/**
	 * Custom comments template.
	 *
	 * @param array $comment    get comment.
	 * @param array $args     arguments.
	 * @param int   $depth    child depth.
	 */
	function capture_comments( $comment, $args, $depth ) {
	?>
		<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
			<?php
			switch ( $comment->comment_type ) :
				case 'pingback':
				case 'trackback':
					?>
					<div id="comment-<?php comment_ID(); ?>">
						<div class="comment-author vcard">
							Pingback: <?php comment_author_link(); ?>
							<?php if ( ! empty( capture_get_settings( 'mts_comment_date' ) ) ) { ?>
								<span class="ago"><?php comment_date( get_option( 'date_format' ) ); ?></span>
							<?php } ?>
							<span class="comment-meta">
								<?php edit_comment_link( __( '( Edit )', 'capture' ), '  ', '' ); ?>
							</span>
						</div>
						<?php if ( '0' === $comment->comment_approved ) : ?>
							<em><?php esc_html_e( 'Your comment is awaiting moderation.', 'capture' ); ?></em>
							<br />
						<?php endif; ?>
					</div>
					<?php
					break;

				default:
					?>
					<div id="comment-<?php comment_ID(); ?>" class="comment-list" itemscope itemtype="http://schema.org/UserComments">
						<div class="comment-author vcard">
							<?php echo get_avatar( $comment->comment_author_email, 65 ); ?>
							<?php printf( '<span class="fn" itemprop="creator" itemscope itemtype="http://schema.org/Person"><span itemprop="name">%s</span></span>', get_comment_author_link() ); ?>
							<span class="comment-meta">
								<?php if ( ! empty( capture_get_settings( 'mts_comment_date' ) ) ) { ?>
									<span class="ago"><?php comment_date( get_option( 'date_format' ) ); ?></span>
								<?php } ?>
								<?php edit_comment_link( __( '( Edit )', 'capture' ), '  ', '' ); ?>
							</span>
							<span class="reply">
								<?php
								comment_reply_link(
									array_merge(
										$args,
										[
											'reply_text' => __( 'Send Reply', 'capture' ),
											'depth'      => $depth,
											'max_depth'  => $args['max_depth'],
										]
									)
								);
								?>
							</span>
						</div>
						<?php if ( '0' === $comment->comment_approved ) : ?>
							<em><?php esc_html_e( 'Your comment is awaiting moderation.', 'capture' ); ?></em>
							<br />
						<?php endif; ?>
						<div class="commentmetadata">
							<div class="commenttext" itemprop="commentText">
								<?php comment_text(); ?>
							</div>
						</div>
					</div>
					<?php
					break;
			endswitch;
			?>
	<!-- WP adds </li> -->
	<?php
	}
}

/**
 * Return "Read More" HTML with a link.
 *
 * @Boolean $icon
 */
if ( ! function_exists( 'get_capture_readmore' ) ) {
	function get_capture_readmore( $icon = false ) {

		if ( $icon ) {
			$icon = '<i class="fa fa-angle-right"></i>';
		} else {
			$icon = '';
		}

		$output  = '<div class="readMore">';
		$output .= '<a href="' . get_the_permalink() . '">' . __( 'Read More', 'capture' ) . $icon . '</a>';
		$output .= '</div>';

		return $output;
	}
}

if ( ! function_exists( 'capture_the_postinfo_item' ) ) {
	/**
	 * Display information of an item.
	 *
	 * @param $item
	*/
	function capture_the_postinfo_item( $item ) {

		$hash = [
			'author'   => '<span class="theauthor"><i class="fa fa-user"></i> <span>' . get_the_author_posts_link() . '</span></span>',
			'date'     => '<span class="thetime date updated"><i class="fa fa-calendar"></i> <span>' . get_the_time( get_option( 'date_format' ) ) . '</span></span>',
			'category' => '<span class="thecategory"><i class="fa fa-tags"></i> ' . capture_get_the_category( ', ' ) . '</span>',
			'comment'  => '<span class="thecomment"><i class="fa fa-comments"></i> <a href="' . esc_url( get_comments_link() ) . '" itemprop="interactionCount"><?php comments_number();?></a></span>',
		];

		return isset( $hash[ $item ] ) ? $hash[ $item ] : '';
	}
}

if ( ! function_exists( 'get_itemprop_3' ) ) {
	// Last item in the breadcrumbs.
	function get_itemprop_3( $title = '', $position = '2' ) {
		echo '<div itemprop="itemListElement" itemscope itemtype="https://schema.org/ListItem">';
		echo '<span itemprop="name">' . $title . '</span>';
		echo '<meta itemprop="position" content="' . $position . '" />';
		echo '</div>';
	}
}
if ( ! function_exists( 'capture_breadcrumbs' ) ) {
	/**
	 * Display the breadcrumbs.
	 */
	function capture_breadcrumbs() {
		if ( is_home() || ! capture_get_settings( 'show_breadcrumb' ) ) {
				return;
		}
		if ( function_exists( 'rank_math_the_breadcrumbs' ) && RankMath\Helper::get_settings( 'general.breadcrumbs' ) ) {
			rank_math_the_breadcrumbs();
			return;
		}
		$seperator = '<div class="separator"></div>';
		echo '<div class="breadcrumb" itemscope itemtype="https://schema.org/BreadcrumbList">';
		echo '<div itemprop="itemListElement" itemscope
	      itemtype="https://schema.org/ListItem" class="root"><a href="';
		echo esc_url( home_url() );
		echo '" itemprop="item"><span itemprop="name">' . esc_html__( 'Home', 'capture' );
		echo '</span><meta itemprop="position" content="1" /></a></div>' . $seperator;
		if ( is_single() ) {
			$categories = get_the_category();
			if ( $categories ) {
				$level         = 0;
				$hierarchy_arr = [];
				foreach ( $categories as $cat ) {
					$anc       = get_ancestors( $cat->term_id, 'category' );
					$count_anc = count( $anc );
					if ( 0 < $count_anc && $level < $count_anc ) {
						$level         = $count_anc;
						$hierarchy_arr = array_reverse( $anc );
						array_push( $hierarchy_arr, $cat->term_id );
					}
				}
				if ( empty( $hierarchy_arr ) ) {
					$category = $categories[0];
					echo '<div itemprop="itemListElement" itemscope
				      itemtype="https://schema.org/ListItem"><a href="' . esc_url( get_category_link( $category->term_id ) ) . '" itemprop="item"><span itemprop="name">' . esc_html( $category->name ) . '</span><meta itemprop="position" content="2" /></a></div>' . $seperator;
				} else {
					foreach ( $hierarchy_arr as $cat_id ) {
						$category = get_term_by( 'id', $cat_id, 'category' );
						echo '<div itemprop="itemListElement" itemscope
					      itemtype="https://schema.org/ListItem"><a href="' . esc_url( get_category_link( $category->term_id ) ) . '" itemprop="item"><span itemprop="name">' . esc_html( $category->name ) . '</span><meta itemprop="position" content="2" /></a></div>' . $seperator;
					}
				}
				get_itemprop_3( get_the_title(), '3' );
			} else {
				get_itemprop_3( get_the_title() );
			}
		} elseif ( is_page() ) {
			$parent_id = wp_get_post_parent_id( get_the_ID() );
			if ( $parent_id ) {
				$breadcrumbs = [];
				while ( $parent_id ) {
					$page          = get_page( $parent_id );
					$breadcrumbs[] = '<div itemprop="itemListElement" itemscope
				      itemtype="https://schema.org/ListItem"><a href="' . esc_url( get_permalink( $page->ID ) ) . '" itemprop="item"><span itemprop="name">' . esc_html( get_the_title( $page->ID ) ) . '</span><meta itemprop="position" content="2" /></a></div>' . $seperator;

					$parent_id = $page->post_parent;
				}
				$breadcrumbs = array_reverse( $breadcrumbs );
				foreach ( $breadcrumbs as $crumb ) {
					echo $crumb;
				}
				get_itemprop_3( get_the_title(), 3 );
			} else {
				get_itemprop_3( get_the_title() );
			}
		} elseif ( is_category() ) {
			global $wp_query;
			$cat_obj       = $wp_query->get_queried_object();
			$this_cat_id   = $cat_obj->term_id;
			$hierarchy_arr = get_ancestors( $this_cat_id, 'category' );
			if ( $hierarchy_arr ) {
				$hierarchy_arr = array_reverse( $hierarchy_arr );
				foreach ( $hierarchy_arr as $cat_id ) {
					$category = get_term_by( 'id', $cat_id, 'category' );
					echo '<div itemprop="itemListElement" itemscope
				      itemtype="https://schema.org/ListItem"><a href="' . esc_url( get_category_link( $category->term_id ) ) . '" itemprop="item"><span itemprop="name">' . esc_html( $category->name ) . '</span><meta itemprop="position" content="2" /></a></div>' . $seperator;
				}
			}
			get_itemprop_3( single_cat_title( '', false ) );
		} elseif ( is_author() ) {
			if ( get_query_var( 'author_name' ) ) :
				$curauth = get_user_by( 'slug', get_query_var( 'author_name' ) );
			else :
				$curauth = get_userdata( get_query_var( 'author' ) );
			endif;
			get_itemprop_3( esc_html( $curauth->nickname ) );
		} elseif ( is_search() ) {
			get_itemprop_3( get_search_query() );
		} elseif ( is_tag() ) {
			get_itemprop_3( single_tag_title( '', false ) );
		}
		echo '</div>';
	}
}

if ( ! empty( capture_get_settings( 'mts_feedburner' ) ) ) {
	/**
	 * Redirect feed to FeedBurner if a FeedBurner URL has been set.
	 */
	function capture_rss_feed_redirect() {
		global $feed;
		$new_feed = capture_get_settings( 'mts_feedburner' );
		if ( ! is_feed() ) {
				return;
		}
		if ( preg_match( '/feedburner/i', $_SERVER['HTTP_USER_AGENT'] ) ) {
				return;
		}
		if ( 'comments-rss2' != $feed ) {
				if ( function_exists( 'status_header' ) ) status_header( 302 );
				header( "Location:" . $new_feed );
				header( "HTTP/1.1 302 Temporary Redirect" );
				exit();
		}
	}
	add_action( 'template_redirect', 'capture_rss_feed_redirect' );
}

if ( ! function_exists( 'get_related_post_thumb' ) ) {
	/**
	 * Related Posts Thumbnail.
	 *
	 * @param  string $thumb post thumbnail image.
	 */
	function get_related_post_thumb( $thumb = 'capture-related' ) {

		?>
		<a href="<?php echo esc_url( get_the_permalink() ); ?>" title="<?php the_title_attribute(); ?>" id="featured-thumbnail">
			<div class="featured-thumbnail">
				<?php the_post_thumbnail( $thumb, [ 'title' => '' ] ); ?>
			</div>
			<?php
			if ( function_exists( 'wp_review_show_total' ) ) {
				wp_review_show_total( true, 'latestPost-review-wrapper' );
			}
			?>
		</a>
		<?php
	}
}

if ( ! function_exists( 'get_blog_post_title' ) ) {
	/**
	 * Related Posts Title.
	 *
	 * @param  string $content post post title.
	 */
	function get_blog_post_title( $content = 'related' ) {
		capture_the_post_meta( $content );
		?>
		<h2 class="title front-view-title"><a href="<?php echo esc_url( get_the_permalink() ); ?>" title="<?php the_title_attribute(); ?>"><?php the_title(); ?></a></h2>
		<?php
	}
}


if ( ! function_exists( 'capture_blog_post_content' ) ) {
	/**
	 * Display Post Content.
	 *
	 * @param string $content content for related posts.
	 */
	function capture_blog_post_content( $content = 'related' ) {
		if ( capture_get_settings( $content . '_post_excerpt' ) ) :
			?>
			<div class="front-view-content">
				<?php
				if ( empty( capture_excerpt() ) ) {
					echo capture_truncate( get_the_content(), capture_get_settings( $content . '_excerpt' ), 'words' );
				} else {
					echo capture_excerpt( capture_get_settings( $content . '_excerpt' ) );
				}
				?>
			</div>
			<?php
		endif;
	}
}

if ( ! function_exists( 'capture_get_readmore_button' ) ) {
	/**
	 * Display Read More Button
	 *
	 * @param string $content content for related posts.
	 */
	function capture_get_readmore_button( $content = 'related' ) {
		if ( capture_get_settings( $content . '_readmore' ) ) :
			$text = capture_get_settings( $content . '_readmore_text' );
			if ( ! empty( $text ) ) {
				?>
				<div class="readMore">
					<a href="<?php the_permalink(); ?>" class="button border" title="<?php the_title_attribute(); ?>"><?php echo $text; ?></a>
				</div>
				<?php
			}
		endif;
	}
}

if ( ! function_exists( 'capture_related_posts_layouts' ) ) {
	/**
	 * Display Related Posts Layout.
	 */
	function capture_related_posts_layouts() {

		$related_posts_layouts = capture_get_settings( 'related_posts_layouts' );
		$related_posts_layouts = $related_posts_layouts ? $related_posts_layouts : 'default';
		// layout grid.
		$grid = capture_get_settings( 'related_posts_grid' );
		$grid = ! empty( $grid ) && 'default' === $related_posts_layouts ? 'flex-grid ' . $grid : 'flex-grid default';

		switch ( $related_posts_layouts ) {
			case 'default':
				?>
				<article class="latestPost excerpt <?php echo esc_attr( $grid ); ?>">
					<?php get_related_post_thumb(); ?>
					<div class="wrapper">
						<?php

						get_blog_post_title();

						capture_blog_post_content();

						capture_get_readmore_button();

						?>
					</div>
				</article><!--.post.excerpt-->
				<?php
				break;

			case 'related2':
				?>
				<article class="latestPost excerpt">

					<?php get_related_post_thumb(); ?>

					<div class="wrapper">
						<?php

						get_blog_post_title();

						capture_blog_post_content();

						capture_get_readmore_button();

						?>
					</div>
				</article><!--.post.excerpt-->
				<?php
				break;

			case 'related3':
				?>
				<article class="latestPost excerpt">
					<div class="wrapper">
						<?php

						get_blog_post_title();

						capture_blog_post_content();

						capture_get_readmore_button();

						?>
					</div>
				</article><!--.post.excerpt-->
				<?php
				break;

			case 'related5':
				$j = 0;
				?>
				<article class="latestPost excerpt flex-grid grid2">
					<?php get_related_post_thumb(); ?>
					<div class="wrapper">
						<?php

						get_blog_post_title();

						capture_blog_post_content();

						capture_get_readmore_button();

						?>
					</div>
				</article><!--.post.excerpt-->
				<?php
				if ( 1 === ++$j ) {
					$ad_code = capture_get_settings( 'related_posts_adcode' );
					if ( ! empty( trim( $ad_code ) ) ) {
						echo '<div class="related-posts-ad">';
							echo do_shortcode( $ad_code );
						echo '</div>';
					}
				}
				break;

			case 'related6':
				?>
				<article class="latestPost excerpt <?php echo esc_attr( $grid ); ?>">
					<div class="wrapper">
						<?php

						get_blog_post_title();

						capture_blog_post_content();

						capture_get_readmore_button();

						?>
					</div>
				</article><!--.post.excerpt-->
				<?php
				break;
		}
	}
}

if ( ! function_exists( 'capture_related_query_args' ) ) {
	/**
	 * Display Related Posts Layout.
	 *
	 * @param array $args content for related posts.
	 */
	function capture_related_query_args( $args ) {

		$related_title = capture_get_settings( 'related_post_title' );
		$position      = capture_get_settings( 'related_posts_position' );
		$my_query      = new WP_Query( $args );
		if ( $my_query->have_posts() ) {
			$title                 = $related_title ? '<div class="related-posts-title"><h4><span>' . $related_title . '</span></h4></div>' : '';
			$related_posts_layouts = capture_get_settings( 'related_posts_layouts' );
			$related_posts_layouts = $related_posts_layouts ? $related_posts_layouts : 'default';
			$position              = ! empty( $position ) ? $position : 'default';
			echo '<div class="related-posts ' . esc_html( $related_posts_layouts ) . ' position-' . esc_html( $position ) . ' ">';
			echo ( 'full' === $position ) ? '<div class="container">' : '';
			echo $title;
			echo '<div class="related-posts-container clear">';

			while ( $my_query->have_posts() ) {
				$my_query->the_post();
				capture_related_posts_layouts();
			}
			echo '</div>';

			if ( 'related6' === $related_posts_layouts ) {
				$ad_code = capture_get_settings( 'related_posts_adcode' );
				if ( ! empty( trim( $ad_code ) ) ) {
					echo '<div class="related-posts-ad">';
						echo do_shortcode( $ad_code );
					echo '</div>';
				}
			}

			echo ( 'full' === $position ) ? '</div>' : '';
			echo '</div>';
		}
	}
}

if ( ! function_exists( 'capture_related_posts' ) ) {
	/**
	 * Display the related posts.
	 */
	function capture_related_posts() {

		$post_id          = get_the_ID();
		$taxonomy         = capture_get_settings( 'mts_related_posts_taxonomy' );
		$related_postsnum = capture_get_settings( 'mts_related_postsnum' );
		$related_postsnum = $related_postsnum ? $related_postsnum : 3;

		if ( ! empty( capture_get_settings( 'mts_single_post_layout' )['enabled']['related'] ) ) {
			$empty_taxonomy = false;
			if ( $taxonomy && 'tags' === $taxonomy ) {
				// related posts based on tags.
				$tags = get_the_tags( $post_id );
				if ( empty( $tags ) ) {
					$empty_taxonomy = true;
				} else {
					$tag_ids = [];
					foreach ( $tags as $individual_tag ) {
						$tag_ids[] = $individual_tag->term_id;
					}
					$args = [
						'tag__in'             => $tag_ids,
						'post__not_in'        => [ $post_id ],
						'posts_per_page'      => $related_postsnum,
						'ignore_sticky_posts' => 1,
						'orderby'             => 'rand',
					];
				}
			} else {
				// related posts based on categories.
				$categories = get_the_category( $post_id );
				if ( empty( $categories ) ) {
					$empty_taxonomy = true;
				} else {
					$category_ids = [];
					foreach ( $categories as $individual_category ) {
						$category_ids[] = $individual_category->term_id;
					}
					$args = [
						'category__in'        => $category_ids,
						'post__not_in'        => [ $post_id ],
						'posts_per_page'      => $related_postsnum,
						'ignore_sticky_posts' => 1,
						'orderby'             => 'rand',
					];
				}
			}
			if ( ! $empty_taxonomy ) {
				capture_related_query_args( $args );
			}
			wp_reset_postdata();
			?>
			<!-- .related-posts -->
			<?php
		}
	}
}

if ( ! function_exists( 'capture_photos_related_posts' ) ) {
	/**
	 * Display the related posts.
	 */
	function capture_photos_related_posts() {
		global $post;
		$custom_taxterms  = wp_get_object_terms( $post->ID, 'photos_categories', [ 'fields' => 'ids' ] );
		$cat              = isset( $category->cat_ID );
		$related_postsnum = capture_get_settings( 'mts_related_postsnum' );
		$related_postsnum = $related_postsnum ? $related_postsnum : 3;
		// arguments.
		$args = [
			'cat'            => $cat,
			'post_type'      => 'photos',
			'post_status'    => 'publish',
			'posts_per_page' => $related_postsnum,
			'orderby'        => 'rand',
			'tax_query'      => [
				[
					'taxonomy' => 'photos_categories',
					'field'    => 'id',
					'terms'    => $custom_taxterms,
				],
			],
			'post__not_in'   => [ $post->ID ],
		];
		$args = apply_filters( 'capture_similar_photos_args', $args, $post->ID );
		capture_related_query_args( $args );
		wp_reset_postdata();
	}
}


if ( ! function_exists( 'capture_social_buttons' ) ) {
	/**
	 * Display the Social Sharing buttons.
	 *
	 * @param string $buttons_pos button position.
	 */
	function capture_social_buttons( $buttons_pos = 'floating' ) {

		$buttons        = [];
		$social_buttons = capture_get_settings( 'mts_social_buttons' );
		$layout         = capture_get_settings( 'social_button_layout' ) ? capture_get_settings( 'social_button_layout' ) : 'default';

		if ( null !== $social_buttons && is_array( $social_buttons ) && array_key_exists( 'enabled', $social_buttons ) ) {
			$buttons = $social_buttons['enabled'];
		}
		if ( ! empty( $buttons ) ) {
			switch ( $layout ) {
				case 'default':
					?>
						<div class="shareit shareit-default <?php echo $buttons_pos; ?>">
							<?php
							foreach ( $buttons as $key => $button ) {
								capture_social_button( $key );
							}
							?>
						</div>
					<?php
					break;

				case 'circular':
				case 'standard':
				case 'circular-standard':
					?>
						<div class="shareit shareit-circular <?php echo $layout . ' ' . $buttons_pos; ?>">
							<?php
							foreach ( $buttons as $key => $button ) {
								capture_social_circular_button( $key );
							}
							?>
						</div>
					<?php
					break;

				default:
					?>
						<div class="shareit shareit-default <?php echo $buttons_pos; ?>">
							<?php
							foreach ( $buttons as $key => $button ) {
								capture_social_button( $key );
							}
							?>
						</div>
					<?php
					break;
			}
		}
	}
}

if ( ! function_exists( 'capture_social_button' ) ) {
	/**
	 * Display network-independent sharing buttons.
	 *
	 * @param string $button social button.
	 */
	function capture_social_button( $button ) {
		$text = esc_html( get_the_title() );
		$link = urlencode( get_permalink() );
		switch ( $button ) {
			case 'facebookshare':
				?>
				<!-- Facebook Share-->
				<span class="share-item facebooksharebtn">
					<div class="fb-share-button" data-layout="button_count"></div>
				</span>
				<?php
				break;
			case 'twitter':
				?>
				<!-- Twitter -->
				<span class="share-item twitterbtn">
					<a href="https://twitter.com/share" class="twitter-share-button" data-via="<?php echo esc_attr( capture_get_settings( 'mts_twitter_username' ) ); ?>"><?php esc_html_e( 'Tweet', 'capture' ); ?></a>
				</span>
				<?php
				break;
			case 'facebook':
				?>
				<!-- Facebook -->
				<span class="share-item facebookbtn">
					<div id="fb-root"></div>
					<div class="fb-like" data-send="false" data-layout="button_count" data-width="150" data-show-faces="false"></div>
				</span>
				<?php
				break;
			case 'pinterest':
				?>
				<!-- Pinterest -->
				<span class="share-item pinbtn">
					<a href="http://pinterest.com/pin/create/button/?url=<?php the_permalink(); ?>&media=<?php $thumb = wp_get_attachment_image_src( get_post_thumbnail_id( get_the_ID() ), 'large' ); echo $thumb['0']; ?>&description=<?php the_title(); ?>" class="pin-it-button" count-layout="horizontal"><?php esc_html_e( 'Pin It', 'capture' ); ?></a>
				</span>
				<?php
				break;
			case 'linkedin':
				?>
				<!--Linkedin -->
				<span class="share-item linkedinbtn">
					<script type="IN/Share" data-url="<?php echo esc_url( get_the_permalink() ); ?>"></script>
				</span>
				<?php
				break;
			case 'reddit':
				?>
				<!-- Reddit -->
				<span class="share-item reddit">
					<a href="//www.reddit.com/submit" onclick="javascript:window.open(this.href, '', 'menubar=no,toolbar=no,resizable=yes,scrollbars=yes,height=600,width=600');return false;"> <img src="<?php echo get_template_directory_uri() . '/images/reddit.png'; ?>" alt=<?php _e( 'submit to reddit', 'capture' ); ?> border="0" /></a>
				</span>
				<?php
				break;
			case 'whatsapp':
				?>
				<!--WhatsApp -->
				<span class="share-item whatsapp">
					<a href="https://wa.me/?text=<?php echo $text . ' ' . $link; ?>" onclick="javascript:window.open(this.href, '', 'menubar=no,toolbar=no,resizable=yes,scrollbars=yes,height=600,width=600');return false;"><span class="icon"><i class="fa fa-whatsapp"></i></span><span class="social-text"><?php _e( 'WhatsApp', 'capture' ); ?></span></a>
				</span>
				<?php
				break;
			case 'telegram':
				?>
				<!-- Telegram -->
					<span class="share-item telegram">
						<a href="javascript:window.open('https://telegram.me/share/url?url='+encodeURIComponent(window.location.href), '_blank')"><span class="icon"><i class="fa fa-paper-plane"></i></span><span class="social-text"><?php _e( 'Telegram', 'capture' ); ?></span></a>
					</span>
				<?php
				break;
			case 'tumblr':
				?>
					<!-- Tumblr -->
					<span class="share-item tumblr">
						<a target="_blank" href="https://www.tumblr.com/widgets/share/tool?canonicalUrl=<?php echo $link; ?>&title=<?php echo $text; ?>"><span class="icon"><i class="fa fa-tumblr"></i></span><span class="social-text"><?php _e( 'Tumblr', 'capture' ); ?></span></a>
					</span>
				<?php
				break;
			case 'pocket':
				?>
					<!-- Pocket -->
					<span class="share-item pocket">
						<a target="_blank" href="https://getpocket.com/save?url=<?php echo $link; ?>&title=<?php echo $text; ?>"><span class="icon"><i class="fa fa-get-pocket"></i></span><span class="social-text"><?php _e( 'Pocket', 'capture' ); ?></span></a>
					</span>
				<?php
				break;
			case 'buffer':
				?>
				<!-- Buffer -->
					<span class="share-item buffer">
						<a target="_blank" href="https://bufferapp.com/add?url=<?php echo $link; ?>&amp;text=<?php echo $text; ?>"><span class="icon"><svg height="18px" id="Layer_1" style="enable-background:new 0 0 512 512;" version="1.1" viewBox="0 0 512 512" width="18px" xml:space="preserve" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"><g><g><path d="M70.7,164.5l169.2,81.7c4.4,2.1,10.3,3.2,16.1,3.2s11.7-1.1,16.1-3.2l169.2-81.7c8.9-4.3,8.9-11.3,0-15.6L272.1,67.2    c-4.4-2.1-10.3-3.2-16.1-3.2s-11.7,1.1-16.1,3.2L70.7,148.9C61.8,153.2,61.8,160.2,70.7,164.5z"/><path d="M441.3,248.2c0,0-30.9-14.9-35-16.9s-5.2-1.9-9.5,0.1s-124.8,60.2-124.8,60.2c-4.5,2.1-10.3,3.2-16.1,3.2    s-11.7-1.1-16.1-3.2c0,0-117.3-56.6-122.8-59.3c-6-2.9-7.7-2.9-13.1-0.3c-5.6,2.7-33.4,16.1-33.4,16.1c-8.9,4.3-8.9,11.3,0,15.6    l169.2,81.7c4.4,2.1,10.3,3.2,16.1,3.2s11.7-1.1,16.1-3.2l169.2-81.7C450.2,259.5,450.2,252.5,441.3,248.2z"/></g><path d="M441.3,347.5c0,0-30.9-14.9-35-16.9s-5.2-1.9-9.5,0.1S272.1,391,272.1,391c-4.5,2.1-10.3,3.2-16.1,3.2s-11.7-1.1-16.1-3.2   c0,0-117.3-56.6-122.8-59.3c-6-2.9-7.7-2.9-13.1-0.3c-5.6,2.7-33.4,16.1-33.4,16.1c-8.9,4.3-8.9,11.3,0,15.6l169.2,81.7   c4.4,2.2,10.3,3.2,16.1,3.2s11.7-1.1,16.1-3.2l169.2-81.7C450.2,358.8,450.2,351.8,441.3,347.5z"/></g></svg></span><span class="social-text"><?php _e( 'Buffer', 'capture' ); ?></span></a>
					</span>
				<?php
				break;
			case 'vkontakte':
				?>
					<!-- Vkontakte -->
					<span class="share-item vkontakte">
						<a target="_blank" href="http://vk.com/share.php?url=<?php echo $link; ?>&title=<?php echo $text; ?>"><span class="icon"><i class="fa fa-vk"></i></span><span class="social-text"><?php _e( 'VK', 'capture' ); ?></span></a>
					</span>
				<?php
				break;
			case 'mix':
				?>
					<!-- Mix -->
					<span class="share-item mix">
						<a target="_blank" href="https://mix.com/add?url=<?php echo $link; ?>"><span class="icon"><svg height="18px" style="enable-background:new 0 0 512 512;" version="1.1" viewBox="0 0 512 512" width="18px" xml:space="preserve" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"><g id="comp_x5F_217-mix"><g><path d="M26.001,54.871v358.246c0,57.705,90.357,59.656,90.357,0V168.124c8.11-54.316,90.357-51.749,90.357,6.675v179.994    c0,59.453,98.57,59.556,98.57,0V235.584c5.44-56.166,90.357-53.906,90.357,4.415v24.44c0,61.503,90.355,58.114,90.355,0V54.871    H26.001z"/></g></g><g id="Layer_1"/></svg></span><span class="social-text"><?php _e( 'Mix', 'capture' ); ?></span></a>
					</span>
				<?php
				break;
		}
	}
}

if ( ! function_exists( 'capture_social_circular_button' ) ) {
	/**
	 * Display network-independent sharing buttons.
	 *
	 * @param string $button social buttons.
	 */
	function capture_social_circular_button( $button ) {
		global $post;
		$text = esc_html( get_the_title() );
		$link = urlencode( get_permalink() );
		if ( is_single() ) {
			$img_url = '';
			$img     = '';
			if ( has_post_thumbnail( $post->ID ) ) {
				$img     = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'capture-featuredfull' );
				$img_url = $img[0];
			}
		}
		switch ( $button ) {
			case 'facebookshare':
				?>
				<!-- Facebook -->
				<a href="//www.facebook.com/share.php?m2w&s=100&p[url]=<?php echo urlencode( get_permalink() ); ?>&p[images][0]=<?php echo urlencode( $img_url[0] ); ?>&p[title]=<?php echo urlencode( get_the_title() ); ?>&u=<?php echo urlencode( get_permalink() ); ?>&t=<?php echo urlencode( get_the_title() ); ?>" class="facebooksharebtn" onclick="javascript:window.open(this.href, '', 'menubar=no,toolbar=no,resizable=yes,scrollbars=yes,height=600,width=600');return false;"><span class="social-icon"><i class="fa fa-facebook-official"></i></span></a>
				<?php
				break;
			case 'twitter':
				?>
				<!-- Twitter -->
				<?php
				$via = '';
				if ( capture_get_settings( 'mts_twitter_username' ) ) {
					$via = '&via=' . capture_get_settings( 'mts_twitter_username' );
				}
				?>
				<a href="https://twitter.com/intent/tweet?original_referer=<?php echo urlencode( get_permalink() ); ?>&text=<?php echo get_the_title(); ?>&url=<?php echo urlencode( get_permalink() ); ?><?php echo $via; ?>" class="twitterbutton" onclick="javascript:window.open(this.href, '', 'menubar=no,toolbar=no,resizable=yes,scrollbars=yes,height=600,width=600');return false;"><span class="social-icon"><i class="fa fa-twitter"></i></span></a>
				<?php
				break;

			case 'pinterest':
				global $post;
				?>
				<!-- Pinterest -->
				<?php $pinterestimage = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'full' ); ?>
				<a href="http://pinterest.com/pin/create/button/?url=<?php echo urlencode( get_permalink( $post->ID ) ); ?>&media=<?php echo $pinterestimage[0]; ?>&description=<?php the_title(); ?>" class="share-pinbtn" onclick="javascript:window.open(this.href, '', 'menubar=no,toolbar=no,resizable=yes,scrollbars=yes,height=600,width=600');return false;"><span class="social-icon"><i class="fa fa-pinterest"></i></span></a>
				<?php
				break;
			case 'linkedin':
				?>
				<!--Linkedin -->
				<a href="//www.linkedin.com/shareArticle?mini=true&url=<?php echo urlencode( get_permalink() ); ?>&title=<?php echo get_the_title(); ?>&source=<?php echo 'url'; ?>" class="linkedinbtn" onclick="javascript:window.open(this.href, '', 'menubar=no,toolbar=no,resizable=yes,scrollbars=yes,height=600,width=600');return false;"><span class="social-icon"><i class="fa fa-linkedin"></i></span></a>
				<?php
				break;
			case 'reddit':
				?>
				<!-- Reddit -->
				<a href="//www.reddit.com/submit" class="reddit" onclick="javascript:window.open(this.href, '', 'menubar=no,toolbar=no,resizable=yes,scrollbars=yes,height=600,width=600');return false;"><span class="social-icon"><i class="fa fa-reddit-alien"></i></span></a>
				<?php
				break;
			case 'whatsapp':
				?>
				<!--WhatsApp -->
				<a href="https://wa.me/?text=<?php echo $text . ' ' . $link; ?>" class="whatsapp" onclick="javascript:window.open(this.href, '', 'menubar=no,toolbar=no,resizable=yes,scrollbars=yes,height=600,width=600');return false;"><span class="social-icon"><i class="fa fa-whatsapp"></i></span></a>
				<?php
				break;
			case 'telegram':
				?>
				<!-- Telegram -->
				<a href="javascript:window.open('https://telegram.me/share/url?url='+encodeURIComponent(window.location.href), '_blank')" class="telegram"><span class="social-icon"><i class="fa fa-paper-plane"></i></span></a>
				<?php
				break;
			case 'tumblr':
				?>
				<!-- Tumblr -->
				<a target="_blank" href="https://www.tumblr.com/widgets/share/tool?canonicalUrl=<?php echo $link; ?>&title=<?php echo $text; ?>" class="tumblr"><span class="social-icon"><i class="fa fa-tumblr"></i></span></a>
				<?php
				break;
			case 'pocket':
				?>
				<!-- Pocket -->
				<a target="_blank" href="https://getpocket.com/save?url=<?php echo $link; ?>&title=<?php echo $text; ?>" class="pocket"><span class="social-icon"><i class="fa fa-get-pocket"></i></span></a>
				<?php
				break;
			case 'buffer':
				?>
				<!-- Buffer -->
				<a target="_blank" href="https://bufferapp.com/add?url=<?php echo $link; ?>&amp;text=<?php echo $text; ?>" class="buffer"><span class="social-icon"><svg height="18px" id="Layer_1" style="enable-background:new 0 0 512 512;" version="1.1" viewBox="0 0 512 512" width="18px" xml:space="preserve" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"><g><g><path d="M70.7,164.5l169.2,81.7c4.4,2.1,10.3,3.2,16.1,3.2s11.7-1.1,16.1-3.2l169.2-81.7c8.9-4.3,8.9-11.3,0-15.6L272.1,67.2    c-4.4-2.1-10.3-3.2-16.1-3.2s-11.7,1.1-16.1,3.2L70.7,148.9C61.8,153.2,61.8,160.2,70.7,164.5z"/><path d="M441.3,248.2c0,0-30.9-14.9-35-16.9s-5.2-1.9-9.5,0.1s-124.8,60.2-124.8,60.2c-4.5,2.1-10.3,3.2-16.1,3.2    s-11.7-1.1-16.1-3.2c0,0-117.3-56.6-122.8-59.3c-6-2.9-7.7-2.9-13.1-0.3c-5.6,2.7-33.4,16.1-33.4,16.1c-8.9,4.3-8.9,11.3,0,15.6    l169.2,81.7c4.4,2.1,10.3,3.2,16.1,3.2s11.7-1.1,16.1-3.2l169.2-81.7C450.2,259.5,450.2,252.5,441.3,248.2z"/></g><path d="M441.3,347.5c0,0-30.9-14.9-35-16.9s-5.2-1.9-9.5,0.1S272.1,391,272.1,391c-4.5,2.1-10.3,3.2-16.1,3.2s-11.7-1.1-16.1-3.2   c0,0-117.3-56.6-122.8-59.3c-6-2.9-7.7-2.9-13.1-0.3c-5.6,2.7-33.4,16.1-33.4,16.1c-8.9,4.3-8.9,11.3,0,15.6l169.2,81.7   c4.4,2.2,10.3,3.2,16.1,3.2s11.7-1.1,16.1-3.2l169.2-81.7C450.2,358.8,450.2,351.8,441.3,347.5z"/></g></svg></span></a>
				<?php
				break;
			case 'vkontakte':
				?>
				<!-- Vkontakte -->
				<a target="_blank" href="http://vk.com/share.php?url=<?php echo $link; ?>&title=<?php echo $text; ?>" class="vkontakte"><span class="social-icon"><i class="fa fa-vk"></i></span></a>
				<?php
				break;
			case 'mix':
				?>
				<!-- Mix -->
				<a target="_blank" href="https://mix.com/add?url=<?php echo $link; ?>" class="mix"><span class="social-icon"><svg height="18px" style="enable-background:new 0 0 512 512;" version="1.1" viewBox="0 0 512 512" width="18px" xml:space="preserve" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"><g id="comp_x5F_217-mix"><g><path d="M26.001,54.871v358.246c0,57.705,90.357,59.656,90.357,0V168.124c8.11-54.316,90.357-51.749,90.357,6.675v179.994    c0,59.453,98.57,59.556,98.57,0V235.584c5.44-56.166,90.357-53.906,90.357,4.415v24.44c0,61.503,90.355,58.114,90.355,0V54.871    H26.001z"/></g></g><g id="Layer_1"/></svg></span></a>
				<?php
				break;
		}
	}
}

if ( ! function_exists( 'capture_blog_articles' ) ) {
	/**
	 * Display a post of specific layout.
	 */
	function capture_blog_articles() {
		?>
		<article class="latestPost excerpt">
			<?php get_related_post_thumb( 'capture-featured' ); ?>
			<div class="wrapper">
				<?php

				get_blog_post_title( 'archive' );

				capture_blog_post_content( 'archive' );

				capture_get_readmore_button( 'archive' );

				?>
			</div>
		</article><!--.post.excerpt-->
		<?php
	}
}

if ( ! function_exists( 'capture_single_full_header_content' ) ) {
	/**
	 * Display a post of specific layout.
	 *
	 * @param string $content content for related posts.
	 */
	function capture_single_full_header_content( $content = 'single' ) {

		?>
		<header>
			<?php
			$next_prev = capture_get_settings( 'header_' . $content . '_prev_next' );
			if ( $next_prev ) :
				?>
				<div class="prev-next btn-prev">
					<?php previous_post_link( '%link', Capture_Images::get_svg( 'prev-arrow' ) . '<span>' . esc_html__( 'Previous', 'capture' ) . '</span>' ); ?>
				</div>
				<?php
			endif;
			?>
			<div class="photos-header-title">
				<?php capture_the_post_meta( $content ); ?>
				<h1 class="single-title"><?php the_title(); ?></h1>
			</div>
			<?php
			if ( $next_prev ) :
				?>
				<div class="prev-next btn-next">
					<?php next_post_link( '%link', '<span>' . esc_html__( 'Next', 'capture' ) . '</span>' . Capture_Images::get_svg( 'next-arrow' ) ); ?>
				</div>
				<?php
			endif;
			?>
		</header>
		<?php
	}
}

/**
 * Display Instagram feeds.
 *
 * Returns a big old hunk of JSON from a non-private IG account page.
 *
 * @param string $username instagram username.
 * @return array
 */
function scrape_insta( $username ) {
	$request         = wp_remote_get( 'http://instagram.com/' . $username );
	$insta_source    = wp_remote_retrieve_body( $request );
	$shards          = explode( 'window._sharedData = ', $insta_source );
	$insta_json      = explode( ';</script>', $shards[1] );
	$insta_array     = json_decode( $insta_json[0], true );
	$update_interval = apply_filters( 'capture_instagram_update_interval', 3600 );
	$insta_serialize = serialize( $insta_array );
	set_transient( 'capture_instagram_' . $username, $insta_serialize, $update_interval );
	return $insta_array;
}
if ( ! function_exists( 'capture_instagram' ) ) {

	function capture_instagram( $username, $number, $force_recapture = false ) {
		$results_serialized = get_transient( 'capture_instagram_' . $username );
		if ( false === $results_serialized ) {
			$results_array = scrape_insta( $username );
		} else {
			$results_array = unserialize( $results_serialized );
		}
		for ( $i = 0; $i < $number; $i++ ) {
			if ( isset( $results_array['entry_data']['ProfilePage'][0]['graphql']['user']['edge_owner_to_timeline_media']['edges'][ $i ] ) ) {
				$latest_array = $results_array['entry_data']['ProfilePage'][0]['graphql']['user']['edge_owner_to_timeline_media']['edges'][ $i ];
				if ( $latest_array['node']['is_video'] ) {
					echo '<a href="http://instagram.com/p/' . $latest_array['node']['shortcode'] . '" target="_blank"><div style="background-image:url(' . preg_replace( '/vp.*\/.{32}\/.{8}\//', '', $latest_array['node']['thumbnail_resources'][2]['src'] ) . ');"></div></a>';
				} else {
					echo '<a href="http://instagram.com/p/' . $latest_array['node']['shortcode'] . '" target="_blank"><div style="background-image:url(' . $latest_array['node']['thumbnail_resources'][2]['src'] . ');"></div></a>';
				}
			}
		}

	}
}

if ( ! function_exists( 'detect_adblocker_notice' ) ) {
	/**
	 * Detect Adblocker Notice
	 *
	 * @return blocker-notice box
	 */
	function detect_adblocker_notice() {
		?>
		<div class="blocker-notice">
			<i class="fa fa-exclamation"></i>
			<h4><?php echo capture_get_settings( 'detect_adblocker_title' ); ?></h4>
			<p><?php echo capture_get_settings( 'detect_adblocker_description' ); ?></p>
			<div><a href="" class="refresh-button"><?php esc_html_e( 'Refresh', 'capture' ); ?></a></div>
		</div>
		<?php
	}
}

if ( ! function_exists( 'show_header_ad' ) ) {
	/**
	 * Show header ad
	 *
	 */
	function show_header_ad() {

		global $template;

		$template = basename( $template );
		$page     = capture_get_settings( 'header_adcode_show' );

		$hash = [
			'all'    => true,
			'home'   => 'page-home.php' === $template,
			'blog'   => is_home() && 'page-home.php' !== $template,
			'single' => is_single(),
			'page'   => is_page() && 'page-home.php' !== $template,
			'both'   => is_home() || is_single(),
		];

		if ( isset( $hash[ $page ] ) && $hash[ $page ] ) {
			get_template_part( 'template-parts/header/header', 'adcode' );
		}

	}
}

if ( ! function_exists( 'capture_featured_layouts' ) ) {
	/**
	 * Blog Layouts
	 *
	 */
	function capture_featured_layouts() {
		include_once get_parent_theme_file_path( 'includes/class-capture-featured-layouts.php' );
		capture()->featured_layouts = new Capture_Featured_Layouts();
		capture()->featured_layouts->render();
	}
}
if ( ! function_exists( 'capture_single_sections' ) ) {
	/**
	 * Single Page
	 *
	 */
	function capture_single_sections() {
		capture()->single_sections = new Capture_Single_Sections();
		capture()->single_sections->render();
	}
}
